/* display.h generated by valac 0.56.19, the Vala compiler, do not modify */

#ifndef __SRC_DISPLAY_H__
#define __SRC_DISPLAY_H__

#include <gee.h>
#include <glib-object.h>
#include <glib.h>
#include <float.h>
#include <math.h>
#include <gio/gio.h>
#include <switchboard.h>
#include <gmodule.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif
#define GETTEXT_PACKAGE "io.elementary.settings.display"
#define LOCALEDIR "/usr/share/locale"

#define DISPLAY_TYPE_MONITOR (display_monitor_get_type ())
#define DISPLAY_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_TYPE_MONITOR, DisplayMonitor))
#define DISPLAY_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DISPLAY_TYPE_MONITOR, DisplayMonitorClass))
#define DISPLAY_IS_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_TYPE_MONITOR))
#define DISPLAY_IS_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DISPLAY_TYPE_MONITOR))
#define DISPLAY_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DISPLAY_TYPE_MONITOR, DisplayMonitorClass))

typedef struct _DisplayMonitor DisplayMonitor;
typedef struct _DisplayMonitorClass DisplayMonitorClass;

#define DISPLAY_TYPE_MONITOR_MODE (display_monitor_mode_get_type ())
#define DISPLAY_MONITOR_MODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_TYPE_MONITOR_MODE, DisplayMonitorMode))
#define DISPLAY_MONITOR_MODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DISPLAY_TYPE_MONITOR_MODE, DisplayMonitorModeClass))
#define DISPLAY_IS_MONITOR_MODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_TYPE_MONITOR_MODE))
#define DISPLAY_IS_MONITOR_MODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DISPLAY_TYPE_MONITOR_MODE))
#define DISPLAY_MONITOR_MODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DISPLAY_TYPE_MONITOR_MODE, DisplayMonitorModeClass))

typedef struct _DisplayMonitorMode DisplayMonitorMode;
typedef struct _DisplayMonitorModeClass DisplayMonitorModeClass;

#define TYPE_SETTINGS_DAEMON (settings_daemon_get_type ())
#define SETTINGS_DAEMON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SETTINGS_DAEMON, SettingsDaemon))
#define IS_SETTINGS_DAEMON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SETTINGS_DAEMON))
#define SETTINGS_DAEMON_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_SETTINGS_DAEMON, SettingsDaemonIface))

typedef struct _SettingsDaemon SettingsDaemon;
typedef struct _SettingsDaemonIface SettingsDaemonIface;

#define TYPE_SETTINGS_DAEMON_PROXY (settings_daemon_proxy_get_type ())

#define DISPLAY_TYPE_PLUG (display_plug_get_type ())
#define DISPLAY_PLUG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_TYPE_PLUG, DisplayPlug))
#define DISPLAY_PLUG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DISPLAY_TYPE_PLUG, DisplayPlugClass))
#define DISPLAY_IS_PLUG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_TYPE_PLUG))
#define DISPLAY_IS_PLUG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DISPLAY_TYPE_PLUG))
#define DISPLAY_PLUG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DISPLAY_TYPE_PLUG, DisplayPlugClass))

typedef struct _DisplayPlug DisplayPlug;
typedef struct _DisplayPlugClass DisplayPlugClass;
typedef struct _DisplayPlugPrivate DisplayPlugPrivate;

#define TYPE_GALA_DBUS (gala_dbus_get_type ())
#define GALA_DBUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GALA_DBUS, GalaDBus))
#define IS_GALA_DBUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GALA_DBUS))
#define GALA_DBUS_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_GALA_DBUS, GalaDBusIface))

typedef struct _GalaDBus GalaDBus;
typedef struct _GalaDBusIface GalaDBusIface;

#define TYPE_GALA_DBUS_PROXY (gala_dbus_proxy_get_type ())

#define TYPE_MONITOR_LABEL_INFO (monitor_label_info_get_type ())
typedef struct _MonitorLabelInfo MonitorLabelInfo;

#define DISPLAY_TYPE_NIGHT_LIGHT_INTERFACE (display_night_light_interface_get_type ())
#define DISPLAY_NIGHT_LIGHT_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_TYPE_NIGHT_LIGHT_INTERFACE, DisplayNightLightInterface))
#define DISPLAY_IS_NIGHT_LIGHT_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_TYPE_NIGHT_LIGHT_INTERFACE))
#define DISPLAY_NIGHT_LIGHT_INTERFACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DISPLAY_TYPE_NIGHT_LIGHT_INTERFACE, DisplayNightLightInterfaceIface))

typedef struct _DisplayNightLightInterface DisplayNightLightInterface;
typedef struct _DisplayNightLightInterfaceIface DisplayNightLightInterfaceIface;

#define DISPLAY_TYPE_NIGHT_LIGHT_INTERFACE_PROXY (display_night_light_interface_proxy_get_type ())

#define DISPLAY_TYPE_NIGHT_LIGHT_MANAGER (display_night_light_manager_get_type ())
#define DISPLAY_NIGHT_LIGHT_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_TYPE_NIGHT_LIGHT_MANAGER, DisplayNightLightManager))
#define DISPLAY_NIGHT_LIGHT_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DISPLAY_TYPE_NIGHT_LIGHT_MANAGER, DisplayNightLightManagerClass))
#define DISPLAY_IS_NIGHT_LIGHT_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_TYPE_NIGHT_LIGHT_MANAGER))
#define DISPLAY_IS_NIGHT_LIGHT_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DISPLAY_TYPE_NIGHT_LIGHT_MANAGER))
#define DISPLAY_NIGHT_LIGHT_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DISPLAY_TYPE_NIGHT_LIGHT_MANAGER, DisplayNightLightManagerClass))

typedef struct _DisplayNightLightManager DisplayNightLightManager;
typedef struct _DisplayNightLightManagerClass DisplayNightLightManagerClass;
typedef struct _DisplayNightLightManagerPrivate DisplayNightLightManagerPrivate;

#define TYPE_MUTTER_DISPLAY_CONFIG_INTERFACE (mutter_display_config_interface_get_type ())
#define MUTTER_DISPLAY_CONFIG_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MUTTER_DISPLAY_CONFIG_INTERFACE, MutterDisplayConfigInterface))
#define IS_MUTTER_DISPLAY_CONFIG_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MUTTER_DISPLAY_CONFIG_INTERFACE))
#define MUTTER_DISPLAY_CONFIG_INTERFACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_MUTTER_DISPLAY_CONFIG_INTERFACE, MutterDisplayConfigInterfaceIface))

typedef struct _MutterDisplayConfigInterface MutterDisplayConfigInterface;
typedef struct _MutterDisplayConfigInterfaceIface MutterDisplayConfigInterfaceIface;

#define TYPE_MUTTER_DISPLAY_CONFIG_INTERFACE_PROXY (mutter_display_config_interface_proxy_get_type ())

#define TYPE_MUTTER_READ_DISPLAY_CRTC (mutter_read_display_crtc_get_type ())
typedef struct _MutterReadDisplayCrtc MutterReadDisplayCrtc;
typedef enum  {
	DISPLAY_TRANSFORM_NORMAL = 0,
	DISPLAY_TRANSFORM_ROTATION_90 = 1,
	DISPLAY_TRANSFORM_ROTATION_180 = 2,
	DISPLAY_TRANSFORM_ROTATION_270 = 3,
	DISPLAY_TRANSFORM_FLIPPED = 4,
	DISPLAY_TRANSFORM_FLIPPED_ROTATION_90 = 5,
	DISPLAY_TRANSFORM_FLIPPED_ROTATION_180 = 6,
	DISPLAY_TRANSFORM_FLIPPED_ROTATION_270 = 7
} DisplayTransform;

#define TYPE_DISPLAY_TRANSFORM (display_transform_get_type ())

#define TYPE_MUTTER_READ_DISPLAY_OUTPUT (mutter_read_display_output_get_type ())
typedef struct _MutterReadDisplayOutput MutterReadDisplayOutput;

#define TYPE_MUTTER_READ_DISPLAY_MODE (mutter_read_display_mode_get_type ())
typedef struct _MutterReadDisplayMode MutterReadDisplayMode;

#define TYPE_MUTTER_WRITE_DISPLAY_CRTC (mutter_write_display_crtc_get_type ())
typedef struct _MutterWriteDisplayCrtc MutterWriteDisplayCrtc;

#define TYPE_MUTTER_WRITE_DISPLAY_OUTPUT (mutter_write_display_output_get_type ())
typedef struct _MutterWriteDisplayOutput MutterWriteDisplayOutput;

#define TYPE_MUTTER_READ_MONITOR (mutter_read_monitor_get_type ())
typedef struct _MutterReadMonitor MutterReadMonitor;

#define TYPE_MUTTER_READ_MONITOR_INFO (mutter_read_monitor_info_get_type ())
typedef struct _MutterReadMonitorInfo MutterReadMonitorInfo;

#define TYPE_MUTTER_READ_MONITOR_MODE (mutter_read_monitor_mode_get_type ())
typedef struct _MutterReadMonitorMode MutterReadMonitorMode;

#define TYPE_MUTTER_READ_LOGICAL_MONITOR (mutter_read_logical_monitor_get_type ())
typedef struct _MutterReadLogicalMonitor MutterReadLogicalMonitor;
typedef enum  {
	MUTTER_APPLY_METHOD_VERIFY = 0,
	MUTTER_APPLY_METHOD_TEMPORARY = 1,
	MUTTER_APPLY_METHOD_PERSISTENT = 2
} MutterApplyMethod;

#define TYPE_MUTTER_APPLY_METHOD (mutter_apply_method_get_type ())

#define TYPE_MUTTER_WRITE_LOGICAL_MONITOR (mutter_write_logical_monitor_get_type ())
typedef struct _MutterWriteLogicalMonitor MutterWriteLogicalMonitor;

#define TYPE_MUTTER_WRITE_MONITOR (mutter_write_monitor_get_type ())
typedef struct _MutterWriteMonitor MutterWriteMonitor;

#define DISPLAY_TYPE_SENSOR_PROXY (display_sensor_proxy_get_type ())
#define DISPLAY_SENSOR_PROXY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_TYPE_SENSOR_PROXY, DisplaySensorProxy))
#define DISPLAY_IS_SENSOR_PROXY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_TYPE_SENSOR_PROXY))
#define DISPLAY_SENSOR_PROXY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), DISPLAY_TYPE_SENSOR_PROXY, DisplaySensorProxyIface))

typedef struct _DisplaySensorProxy DisplaySensorProxy;
typedef struct _DisplaySensorProxyIface DisplaySensorProxyIface;

#define DISPLAY_TYPE_SENSOR_PROXY_PROXY (display_sensor_proxy_proxy_get_type ())

#define DISPLAY_TYPE_SENSOR_MANAGER (display_sensor_manager_get_type ())
#define DISPLAY_SENSOR_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_TYPE_SENSOR_MANAGER, DisplaySensorManager))
#define DISPLAY_SENSOR_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DISPLAY_TYPE_SENSOR_MANAGER, DisplaySensorManagerClass))
#define DISPLAY_IS_SENSOR_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_TYPE_SENSOR_MANAGER))
#define DISPLAY_IS_SENSOR_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DISPLAY_TYPE_SENSOR_MANAGER))
#define DISPLAY_SENSOR_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DISPLAY_TYPE_SENSOR_MANAGER, DisplaySensorManagerClass))

typedef struct _DisplaySensorManager DisplaySensorManager;
typedef struct _DisplaySensorManagerClass DisplaySensorManagerClass;
typedef struct _DisplaySensorManagerPrivate DisplaySensorManagerPrivate;

#define DISPLAY_TYPE_VIRTUAL_MONITOR (display_virtual_monitor_get_type ())
#define DISPLAY_VIRTUAL_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_TYPE_VIRTUAL_MONITOR, DisplayVirtualMonitor))
#define DISPLAY_VIRTUAL_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DISPLAY_TYPE_VIRTUAL_MONITOR, DisplayVirtualMonitorClass))
#define DISPLAY_IS_VIRTUAL_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_TYPE_VIRTUAL_MONITOR))
#define DISPLAY_IS_VIRTUAL_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DISPLAY_TYPE_VIRTUAL_MONITOR))
#define DISPLAY_VIRTUAL_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DISPLAY_TYPE_VIRTUAL_MONITOR, DisplayVirtualMonitorClass))

typedef struct _DisplayVirtualMonitor DisplayVirtualMonitor;
typedef struct _DisplayVirtualMonitorClass DisplayVirtualMonitorClass;
typedef struct _DisplayVirtualMonitorPrivate DisplayVirtualMonitorPrivate;

#define DISPLAY_VIRTUAL_MONITOR_TYPE_SCALE (display_virtual_monitor_scale_get_type ())
#define DISPLAY_VIRTUAL_MONITOR_SCALE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_VIRTUAL_MONITOR_TYPE_SCALE, DisplayVirtualMonitorScale))
#define DISPLAY_VIRTUAL_MONITOR_SCALE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DISPLAY_VIRTUAL_MONITOR_TYPE_SCALE, DisplayVirtualMonitorScaleClass))
#define DISPLAY_VIRTUAL_MONITOR_IS_SCALE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_VIRTUAL_MONITOR_TYPE_SCALE))
#define DISPLAY_VIRTUAL_MONITOR_IS_SCALE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DISPLAY_VIRTUAL_MONITOR_TYPE_SCALE))
#define DISPLAY_VIRTUAL_MONITOR_SCALE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DISPLAY_VIRTUAL_MONITOR_TYPE_SCALE, DisplayVirtualMonitorScaleClass))

typedef struct _DisplayVirtualMonitorScale DisplayVirtualMonitorScale;
typedef struct _DisplayVirtualMonitorScaleClass DisplayVirtualMonitorScaleClass;
typedef struct _DisplayVirtualMonitorScalePrivate DisplayVirtualMonitorScalePrivate;

#define DISPLAY_VIRTUAL_MONITOR_TYPE_TRANSFORM (display_virtual_monitor_transform_get_type ())
#define DISPLAY_VIRTUAL_MONITOR_TRANSFORM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_VIRTUAL_MONITOR_TYPE_TRANSFORM, DisplayVirtualMonitorTransform))
#define DISPLAY_VIRTUAL_MONITOR_TRANSFORM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DISPLAY_VIRTUAL_MONITOR_TYPE_TRANSFORM, DisplayVirtualMonitorTransformClass))
#define DISPLAY_VIRTUAL_MONITOR_IS_TRANSFORM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_VIRTUAL_MONITOR_TYPE_TRANSFORM))
#define DISPLAY_VIRTUAL_MONITOR_IS_TRANSFORM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DISPLAY_VIRTUAL_MONITOR_TYPE_TRANSFORM))
#define DISPLAY_VIRTUAL_MONITOR_TRANSFORM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DISPLAY_VIRTUAL_MONITOR_TYPE_TRANSFORM, DisplayVirtualMonitorTransformClass))

typedef struct _DisplayVirtualMonitorTransform DisplayVirtualMonitorTransform;
typedef struct _DisplayVirtualMonitorTransformClass DisplayVirtualMonitorTransformClass;
typedef struct _DisplayVirtualMonitorTransformPrivate DisplayVirtualMonitorTransformPrivate;
typedef struct _DisplayMonitorModePrivate DisplayMonitorModePrivate;

#define DISPLAY_TYPE_MONITOR_MANAGER (display_monitor_manager_get_type ())
#define DISPLAY_MONITOR_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_TYPE_MONITOR_MANAGER, DisplayMonitorManager))
#define DISPLAY_MONITOR_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DISPLAY_TYPE_MONITOR_MANAGER, DisplayMonitorManagerClass))
#define DISPLAY_IS_MONITOR_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_TYPE_MONITOR_MANAGER))
#define DISPLAY_IS_MONITOR_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DISPLAY_TYPE_MONITOR_MANAGER))
#define DISPLAY_MONITOR_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DISPLAY_TYPE_MONITOR_MANAGER, DisplayMonitorManagerClass))

typedef struct _DisplayMonitorManager DisplayMonitorManager;
typedef struct _DisplayMonitorManagerClass DisplayMonitorManagerClass;
typedef struct _DisplayMonitorManagerPrivate DisplayMonitorManagerPrivate;
typedef struct _DisplayMonitorPrivate DisplayMonitorPrivate;

#define DISPLAY_TYPE_NIGHT_LIGHT_VIEW (display_night_light_view_get_type ())
#define DISPLAY_NIGHT_LIGHT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_TYPE_NIGHT_LIGHT_VIEW, DisplayNightLightView))
#define DISPLAY_NIGHT_LIGHT_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DISPLAY_TYPE_NIGHT_LIGHT_VIEW, DisplayNightLightViewClass))
#define DISPLAY_IS_NIGHT_LIGHT_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_TYPE_NIGHT_LIGHT_VIEW))
#define DISPLAY_IS_NIGHT_LIGHT_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DISPLAY_TYPE_NIGHT_LIGHT_VIEW))
#define DISPLAY_NIGHT_LIGHT_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DISPLAY_TYPE_NIGHT_LIGHT_VIEW, DisplayNightLightViewClass))

typedef struct _DisplayNightLightView DisplayNightLightView;
typedef struct _DisplayNightLightViewClass DisplayNightLightViewClass;
typedef struct _DisplayNightLightViewPrivate DisplayNightLightViewPrivate;

#define DISPLAY_TYPE_DISPLAYS_VIEW (display_displays_view_get_type ())
#define DISPLAY_DISPLAYS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_TYPE_DISPLAYS_VIEW, DisplayDisplaysView))
#define DISPLAY_DISPLAYS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DISPLAY_TYPE_DISPLAYS_VIEW, DisplayDisplaysViewClass))
#define DISPLAY_IS_DISPLAYS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_TYPE_DISPLAYS_VIEW))
#define DISPLAY_IS_DISPLAYS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DISPLAY_TYPE_DISPLAYS_VIEW))
#define DISPLAY_DISPLAYS_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DISPLAY_TYPE_DISPLAYS_VIEW, DisplayDisplaysViewClass))

typedef struct _DisplayDisplaysView DisplayDisplaysView;
typedef struct _DisplayDisplaysViewClass DisplayDisplaysViewClass;
typedef struct _DisplayDisplaysViewPrivate DisplayDisplaysViewPrivate;

#define DISPLAY_TYPE_DISPLAYS_OVERLAY (display_displays_overlay_get_type ())
#define DISPLAY_DISPLAYS_OVERLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_TYPE_DISPLAYS_OVERLAY, DisplayDisplaysOverlay))
#define DISPLAY_DISPLAYS_OVERLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DISPLAY_TYPE_DISPLAYS_OVERLAY, DisplayDisplaysOverlayClass))
#define DISPLAY_IS_DISPLAYS_OVERLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_TYPE_DISPLAYS_OVERLAY))
#define DISPLAY_IS_DISPLAYS_OVERLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DISPLAY_TYPE_DISPLAYS_OVERLAY))
#define DISPLAY_DISPLAYS_OVERLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DISPLAY_TYPE_DISPLAYS_OVERLAY, DisplayDisplaysOverlayClass))

typedef struct _DisplayDisplaysOverlay DisplayDisplaysOverlay;
typedef struct _DisplayDisplaysOverlayClass DisplayDisplaysOverlayClass;

#define DISPLAY_TYPE_FILTERS_VIEW (display_filters_view_get_type ())
#define DISPLAY_FILTERS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_TYPE_FILTERS_VIEW, DisplayFiltersView))
#define DISPLAY_FILTERS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DISPLAY_TYPE_FILTERS_VIEW, DisplayFiltersViewClass))
#define DISPLAY_IS_FILTERS_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_TYPE_FILTERS_VIEW))
#define DISPLAY_IS_FILTERS_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DISPLAY_TYPE_FILTERS_VIEW))
#define DISPLAY_FILTERS_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DISPLAY_TYPE_FILTERS_VIEW, DisplayFiltersViewClass))

typedef struct _DisplayFiltersView DisplayFiltersView;
typedef struct _DisplayFiltersViewClass DisplayFiltersViewClass;
typedef struct _DisplayFiltersViewPrivate DisplayFiltersViewPrivate;

#define DISPLAY_TYPE_RESOLUTION (display_resolution_get_type ())
typedef struct _DisplayResolution DisplayResolution;

#define DISPLAY_TYPE_DISPLAY_WIDGET (display_display_widget_get_type ())
#define DISPLAY_DISPLAY_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_TYPE_DISPLAY_WIDGET, DisplayDisplayWidget))
#define DISPLAY_DISPLAY_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DISPLAY_TYPE_DISPLAY_WIDGET, DisplayDisplayWidgetClass))
#define DISPLAY_IS_DISPLAY_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_TYPE_DISPLAY_WIDGET))
#define DISPLAY_IS_DISPLAY_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DISPLAY_TYPE_DISPLAY_WIDGET))
#define DISPLAY_DISPLAY_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DISPLAY_TYPE_DISPLAY_WIDGET, DisplayDisplayWidgetClass))

typedef struct _DisplayDisplayWidget DisplayDisplayWidget;
typedef struct _DisplayDisplayWidgetClass DisplayDisplayWidgetClass;
typedef struct _DisplayDisplayWidgetPrivate DisplayDisplayWidgetPrivate;
typedef struct _DisplayDisplaysOverlayPrivate DisplayDisplaysOverlayPrivate;

struct _SettingsDaemonIface {
	GTypeInterface parent_iface;
	void (*apply_configuration) (SettingsDaemon* self, gint64 parent_window_xid, gint64 timestamp, GError** error);
};

struct _DisplayPlug {
	SwitchboardPlug parent_instance;
	DisplayPlugPrivate * priv;
};

struct _DisplayPlugClass {
	SwitchboardPlugClass parent_class;
};

struct _MonitorLabelInfo {
	gint monitor;
	gchar* label;
	gchar* background_color;
	gchar* text_color;
	gint x;
	gint y;
};

struct _GalaDBusIface {
	GTypeInterface parent_iface;
	void (*show_monitor_labels) (GalaDBus* self, MonitorLabelInfo* label_infos, gint label_infos_length1, GError** error);
	void (*hide_monitor_labels) (GalaDBus* self, GError** error);
};

struct _DisplayNightLightInterfaceIface {
	GTypeInterface parent_iface;
	gboolean (*get_disabled_until_tomorrow) (DisplayNightLightInterface* self);
	void (*set_disabled_until_tomorrow) (DisplayNightLightInterface* self, gboolean value);
};

struct _DisplayNightLightManager {
	GObject parent_instance;
	DisplayNightLightManagerPrivate * priv;
};

struct _DisplayNightLightManagerClass {
	GObjectClass parent_class;
};

struct _MutterReadDisplayCrtc {
	guint id;
	gint64 winsys_id;
	gint x;
	gint y;
	gint width;
	gint height;
	gint current_mode;
	DisplayTransform current_transform;
	DisplayTransform* transforms;
	gint transforms_length1;
	GHashTable* properties;
};

struct _MutterReadDisplayOutput {
	guint id;
	gint64 winsys_id;
	gint current_crtc;
	guint* possible_crtcs;
	gint possible_crtcs_length1;
	gchar* connector_name;
	guint* modes;
	gint modes_length1;
	guint* clones;
	gint clones_length1;
	GHashTable* properties;
};

struct _MutterReadDisplayMode {
	guint id;
	gint64 winsys_id;
	guint width;
	guint height;
	gdouble frequency;
	guint flags;
};

struct _MutterWriteDisplayCrtc {
	guint id;
	gint new_mode;
	gint x;
	gint y;
	DisplayTransform transform;
	guint* outputs;
	gint outputs_length1;
	GHashTable* properties;
};

struct _MutterWriteDisplayOutput {
	guint id;
	GHashTable* properties;
};

struct _MutterReadMonitorInfo {
	gchar* connector;
	gchar* vendor;
	gchar* product;
	gchar* serial;
};

struct _MutterReadMonitorMode {
	gchar* id;
	gint width;
	gint height;
	gdouble frequency;
	gdouble preferred_scale;
	gdouble* supported_scales;
	gint supported_scales_length1;
	GHashTable* properties;
};

struct _MutterReadMonitor {
	MutterReadMonitorInfo monitor;
	MutterReadMonitorMode* modes;
	gint modes_length1;
	GHashTable* properties;
};

struct _MutterReadLogicalMonitor {
	gint x;
	gint y;
	gdouble scale;
	DisplayTransform transform;
	gboolean primary;
	MutterReadMonitorInfo* monitors;
	gint monitors_length1;
	GHashTable* properties;
};

struct _MutterWriteMonitor {
	gchar* connector;
	gchar* monitor_mode;
	GHashTable* properties;
};

struct _MutterWriteLogicalMonitor {
	gint x;
	gint y;
	gdouble scale;
	DisplayTransform transform;
	gboolean primary;
	MutterWriteMonitor* monitors;
	gint monitors_length1;
};

struct _MutterDisplayConfigInterfaceIface {
	GTypeInterface parent_iface;
	void (*get_resources) (MutterDisplayConfigInterface* self, guint* serial, MutterReadDisplayCrtc** crtcs, gint* crtcs_length1, MutterReadDisplayOutput** outputs, gint* outputs_length1, MutterReadDisplayMode** modes, gint* modes_length1, gint* max_screen_width, gint* max_screen_height, GError** error);
	void (*apply_configuration) (MutterDisplayConfigInterface* self, guint serial, gboolean persistent, MutterWriteDisplayCrtc* crtcs, gint crtcs_length1, MutterWriteDisplayOutput* outputs, gint outputs_length1, GError** error);
	gint (*change_backlight) (MutterDisplayConfigInterface* self, guint serial, guint output, gint value, GError** error);
	void (*get_crtc_gamma) (MutterDisplayConfigInterface* self, guint serial, guint crtc, guint** red, gint* red_length1, guint** green, gint* green_length1, guint** blue, gint* blue_length1, GError** error);
	void (*set_crtc_gamma) (MutterDisplayConfigInterface* self, guint serial, guint crtc, guint* red, gint red_length1, guint* green, gint green_length1, guint* blue, gint blue_length1, GError** error);
	void (*get_current_state) (MutterDisplayConfigInterface* self, guint* serial, MutterReadMonitor** monitors, gint* monitors_length1, MutterReadLogicalMonitor** logical_monitors, gint* logical_monitors_length1, GHashTable** properties, GError** error);
	void (*apply_monitors_config) (MutterDisplayConfigInterface* self, guint serial, MutterApplyMethod method, MutterWriteLogicalMonitor* logical_monitors, gint logical_monitors_length1, GHashTable* properties, GError** error);
	gint (*get_power_save_mode) (MutterDisplayConfigInterface* self);
	void (*set_power_save_mode) (MutterDisplayConfigInterface* self, gint value);
};

struct _DisplaySensorProxyIface {
	GTypeInterface parent_iface;
	gboolean (*get_has_accelerometer) (DisplaySensorProxy* self);
};

struct _DisplaySensorManager {
	GObject parent_instance;
	DisplaySensorManagerPrivate * priv;
};

struct _DisplaySensorManagerClass {
	GObjectClass parent_class;
};

struct _DisplayVirtualMonitor {
	GObject parent_instance;
	DisplayVirtualMonitorPrivate * priv;
};

struct _DisplayVirtualMonitorClass {
	GObjectClass parent_class;
};

struct _DisplayVirtualMonitorScale {
	GObject parent_instance;
	DisplayVirtualMonitorScalePrivate * priv;
};

struct _DisplayVirtualMonitorScaleClass {
	GObjectClass parent_class;
};

struct _DisplayVirtualMonitorTransform {
	GObject parent_instance;
	DisplayVirtualMonitorTransformPrivate * priv;
};

struct _DisplayVirtualMonitorTransformClass {
	GObjectClass parent_class;
};

struct _DisplayMonitorMode {
	GObject parent_instance;
	DisplayMonitorModePrivate * priv;
	gdouble* supported_scales;
	gint supported_scales_length1;
};

struct _DisplayMonitorModeClass {
	GObjectClass parent_class;
};

struct _DisplayMonitorManager {
	GObject parent_instance;
	DisplayMonitorManagerPrivate * priv;
};

struct _DisplayMonitorManagerClass {
	GObjectClass parent_class;
};

struct _DisplayMonitor {
	GObject parent_instance;
	DisplayMonitorPrivate * priv;
};

struct _DisplayMonitorClass {
	GObjectClass parent_class;
};

struct _DisplayNightLightView {
	GtkBox parent_instance;
	DisplayNightLightViewPrivate * priv;
};

struct _DisplayNightLightViewClass {
	GtkBoxClass parent_class;
};

struct _DisplayDisplaysView {
	GtkBox parent_instance;
	DisplayDisplaysViewPrivate * priv;
	DisplayDisplaysOverlay* displays_overlay;
};

struct _DisplayDisplaysViewClass {
	GtkBoxClass parent_class;
};

struct _DisplayFiltersView {
	GtkBox parent_instance;
	DisplayFiltersViewPrivate * priv;
};

struct _DisplayFiltersViewClass {
	GtkBoxClass parent_class;
};

struct _DisplayResolution {
	gint width;
	gint height;
	gint aspect;
	gboolean is_preferred;
	gboolean is_current;
};

struct _DisplayDisplayWidget {
	GtkBox parent_instance;
	DisplayDisplayWidgetPrivate * priv;
};

struct _DisplayDisplayWidgetClass {
	GtkBoxClass parent_class;
};

struct _DisplayDisplaysOverlay {
	GtkBox parent_instance;
	DisplayDisplaysOverlayPrivate * priv;
};

struct _DisplayDisplaysOverlayClass {
	GtkBoxClass parent_class;
};

VALA_EXTERN GType display_monitor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DisplayMonitor, g_object_unref)
VALA_EXTERN GType display_monitor_mode_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DisplayMonitorMode, g_object_unref)
VALA_EXTERN GeeLinkedList* display_utils_get_common_monitor_modes (GeeLinkedList* monitors);
VALA_EXTERN gdouble display_utils_get_min_compatible_scale (GeeLinkedList* monitors);
VALA_EXTERN GType settings_daemon_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint settings_daemon_register_object (void* object,
                                       GDBusConnection* connection,
                                       const gchar* path,
                                       GError** error);
VALA_EXTERN GType settings_daemon_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SettingsDaemon, g_object_unref)
VALA_EXTERN void settings_daemon_apply_configuration (SettingsDaemon* self,
                                          gint64 parent_window_xid,
                                          gint64 timestamp,
                                          GError** error);
VALA_EXTERN SettingsDaemon* get_settings_daemon (GError** error);
VALA_EXTERN GType display_plug_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DisplayPlug, g_object_unref)
VALA_EXTERN DisplayPlug* display_plug_plug;
VALA_EXTERN DisplayPlug* display_plug_new (void);
VALA_EXTERN DisplayPlug* display_plug_construct (GType object_type);
VALA_EXTERN SwitchboardPlug* get_plug (GModule* module);
VALA_EXTERN GType gala_dbus_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint gala_dbus_register_object (void* object,
                                 GDBusConnection* connection,
                                 const gchar* path,
                                 GError** error);
VALA_EXTERN GType monitor_label_info_get_type (void) G_GNUC_CONST ;
VALA_EXTERN MonitorLabelInfo* monitor_label_info_dup (const MonitorLabelInfo* self);
VALA_EXTERN void monitor_label_info_free (MonitorLabelInfo* self);
VALA_EXTERN void monitor_label_info_copy (const MonitorLabelInfo* self,
                              MonitorLabelInfo* dest);
VALA_EXTERN void monitor_label_info_destroy (MonitorLabelInfo* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (MonitorLabelInfo, monitor_label_info_destroy)
VALA_EXTERN GType gala_dbus_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GalaDBus, g_object_unref)
VALA_EXTERN void gala_dbus_show_monitor_labels (GalaDBus* self,
                                    MonitorLabelInfo* label_infos,
                                    gint label_infos_length1,
                                    GError** error);
VALA_EXTERN void gala_dbus_hide_monitor_labels (GalaDBus* self,
                                    GError** error);
VALA_EXTERN GType display_night_light_interface_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DisplayNightLightInterface, g_object_unref)
VALA_EXTERN GType display_night_light_interface_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint display_night_light_interface_register_object (void* object,
                                                     GDBusConnection* connection,
                                                     const gchar* path,
                                                     GError** error);
VALA_EXTERN gboolean display_night_light_interface_get_disabled_until_tomorrow (DisplayNightLightInterface* self);
VALA_EXTERN void display_night_light_interface_set_disabled_until_tomorrow (DisplayNightLightInterface* self,
                                                                gboolean value);
VALA_EXTERN GType display_night_light_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DisplayNightLightManager, g_object_unref)
VALA_EXTERN DisplayNightLightManager* display_night_light_manager_get_instance (void);
VALA_EXTERN gboolean display_night_light_manager_get_snoozed (DisplayNightLightManager* self);
VALA_EXTERN void display_night_light_manager_set_snoozed (DisplayNightLightManager* self,
                                              gboolean value);
VALA_EXTERN GType mutter_display_config_interface_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint mutter_display_config_interface_register_object (void* object,
                                                       GDBusConnection* connection,
                                                       const gchar* path,
                                                       GError** error);
VALA_EXTERN GType mutter_read_display_crtc_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType display_transform_get_type (void) G_GNUC_CONST ;
VALA_EXTERN MutterReadDisplayCrtc* mutter_read_display_crtc_dup (const MutterReadDisplayCrtc* self);
VALA_EXTERN void mutter_read_display_crtc_free (MutterReadDisplayCrtc* self);
VALA_EXTERN void mutter_read_display_crtc_copy (const MutterReadDisplayCrtc* self,
                                    MutterReadDisplayCrtc* dest);
VALA_EXTERN void mutter_read_display_crtc_destroy (MutterReadDisplayCrtc* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (MutterReadDisplayCrtc, mutter_read_display_crtc_destroy)
VALA_EXTERN GType mutter_read_display_output_get_type (void) G_GNUC_CONST ;
VALA_EXTERN MutterReadDisplayOutput* mutter_read_display_output_dup (const MutterReadDisplayOutput* self);
VALA_EXTERN void mutter_read_display_output_free (MutterReadDisplayOutput* self);
VALA_EXTERN void mutter_read_display_output_copy (const MutterReadDisplayOutput* self,
                                      MutterReadDisplayOutput* dest);
VALA_EXTERN void mutter_read_display_output_destroy (MutterReadDisplayOutput* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (MutterReadDisplayOutput, mutter_read_display_output_destroy)
VALA_EXTERN GType mutter_read_display_mode_get_type (void) G_GNUC_CONST ;
VALA_EXTERN MutterReadDisplayMode* mutter_read_display_mode_dup (const MutterReadDisplayMode* self);
VALA_EXTERN void mutter_read_display_mode_free (MutterReadDisplayMode* self);
VALA_EXTERN GType mutter_write_display_crtc_get_type (void) G_GNUC_CONST ;
VALA_EXTERN MutterWriteDisplayCrtc* mutter_write_display_crtc_dup (const MutterWriteDisplayCrtc* self);
VALA_EXTERN void mutter_write_display_crtc_free (MutterWriteDisplayCrtc* self);
VALA_EXTERN void mutter_write_display_crtc_copy (const MutterWriteDisplayCrtc* self,
                                     MutterWriteDisplayCrtc* dest);
VALA_EXTERN void mutter_write_display_crtc_destroy (MutterWriteDisplayCrtc* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (MutterWriteDisplayCrtc, mutter_write_display_crtc_destroy)
VALA_EXTERN GType mutter_write_display_output_get_type (void) G_GNUC_CONST ;
VALA_EXTERN MutterWriteDisplayOutput* mutter_write_display_output_dup (const MutterWriteDisplayOutput* self);
VALA_EXTERN void mutter_write_display_output_free (MutterWriteDisplayOutput* self);
VALA_EXTERN void mutter_write_display_output_copy (const MutterWriteDisplayOutput* self,
                                       MutterWriteDisplayOutput* dest);
VALA_EXTERN void mutter_write_display_output_destroy (MutterWriteDisplayOutput* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (MutterWriteDisplayOutput, mutter_write_display_output_destroy)
VALA_EXTERN GType mutter_read_monitor_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType mutter_read_monitor_info_get_type (void) G_GNUC_CONST ;
VALA_EXTERN MutterReadMonitorInfo* mutter_read_monitor_info_dup (const MutterReadMonitorInfo* self);
VALA_EXTERN void mutter_read_monitor_info_free (MutterReadMonitorInfo* self);
VALA_EXTERN void mutter_read_monitor_info_copy (const MutterReadMonitorInfo* self,
                                    MutterReadMonitorInfo* dest);
VALA_EXTERN void mutter_read_monitor_info_destroy (MutterReadMonitorInfo* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (MutterReadMonitorInfo, mutter_read_monitor_info_destroy)
VALA_EXTERN GType mutter_read_monitor_mode_get_type (void) G_GNUC_CONST ;
VALA_EXTERN MutterReadMonitorMode* mutter_read_monitor_mode_dup (const MutterReadMonitorMode* self);
VALA_EXTERN void mutter_read_monitor_mode_free (MutterReadMonitorMode* self);
VALA_EXTERN void mutter_read_monitor_mode_copy (const MutterReadMonitorMode* self,
                                    MutterReadMonitorMode* dest);
VALA_EXTERN void mutter_read_monitor_mode_destroy (MutterReadMonitorMode* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (MutterReadMonitorMode, mutter_read_monitor_mode_destroy)
VALA_EXTERN MutterReadMonitor* mutter_read_monitor_dup (const MutterReadMonitor* self);
VALA_EXTERN void mutter_read_monitor_free (MutterReadMonitor* self);
VALA_EXTERN void mutter_read_monitor_copy (const MutterReadMonitor* self,
                               MutterReadMonitor* dest);
VALA_EXTERN void mutter_read_monitor_destroy (MutterReadMonitor* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (MutterReadMonitor, mutter_read_monitor_destroy)
VALA_EXTERN GType mutter_read_logical_monitor_get_type (void) G_GNUC_CONST ;
VALA_EXTERN MutterReadLogicalMonitor* mutter_read_logical_monitor_dup (const MutterReadLogicalMonitor* self);
VALA_EXTERN void mutter_read_logical_monitor_free (MutterReadLogicalMonitor* self);
VALA_EXTERN void mutter_read_logical_monitor_copy (const MutterReadLogicalMonitor* self,
                                       MutterReadLogicalMonitor* dest);
VALA_EXTERN void mutter_read_logical_monitor_destroy (MutterReadLogicalMonitor* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (MutterReadLogicalMonitor, mutter_read_logical_monitor_destroy)
VALA_EXTERN GType mutter_apply_method_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType mutter_write_logical_monitor_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType mutter_write_monitor_get_type (void) G_GNUC_CONST ;
VALA_EXTERN MutterWriteMonitor* mutter_write_monitor_dup (const MutterWriteMonitor* self);
VALA_EXTERN void mutter_write_monitor_free (MutterWriteMonitor* self);
VALA_EXTERN void mutter_write_monitor_copy (const MutterWriteMonitor* self,
                                MutterWriteMonitor* dest);
VALA_EXTERN void mutter_write_monitor_destroy (MutterWriteMonitor* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (MutterWriteMonitor, mutter_write_monitor_destroy)
VALA_EXTERN MutterWriteLogicalMonitor* mutter_write_logical_monitor_dup (const MutterWriteLogicalMonitor* self);
VALA_EXTERN void mutter_write_logical_monitor_free (MutterWriteLogicalMonitor* self);
VALA_EXTERN void mutter_write_logical_monitor_copy (const MutterWriteLogicalMonitor* self,
                                        MutterWriteLogicalMonitor* dest);
VALA_EXTERN void mutter_write_logical_monitor_destroy (MutterWriteLogicalMonitor* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (MutterWriteLogicalMonitor, mutter_write_logical_monitor_destroy)
VALA_EXTERN GType mutter_display_config_interface_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MutterDisplayConfigInterface, g_object_unref)
VALA_EXTERN void mutter_display_config_interface_get_resources (MutterDisplayConfigInterface* self,
                                                    guint* serial,
                                                    MutterReadDisplayCrtc** crtcs,
                                                    gint* crtcs_length1,
                                                    MutterReadDisplayOutput** outputs,
                                                    gint* outputs_length1,
                                                    MutterReadDisplayMode** modes,
                                                    gint* modes_length1,
                                                    gint* max_screen_width,
                                                    gint* max_screen_height,
                                                    GError** error);
VALA_EXTERN void mutter_display_config_interface_apply_configuration (MutterDisplayConfigInterface* self,
                                                          guint serial,
                                                          gboolean persistent,
                                                          MutterWriteDisplayCrtc* crtcs,
                                                          gint crtcs_length1,
                                                          MutterWriteDisplayOutput* outputs,
                                                          gint outputs_length1,
                                                          GError** error);
VALA_EXTERN gint mutter_display_config_interface_change_backlight (MutterDisplayConfigInterface* self,
                                                       guint serial,
                                                       guint output,
                                                       gint value,
                                                       GError** error);
VALA_EXTERN void mutter_display_config_interface_get_crtc_gamma (MutterDisplayConfigInterface* self,
                                                     guint serial,
                                                     guint crtc,
                                                     guint** red,
                                                     gint* red_length1,
                                                     guint** green,
                                                     gint* green_length1,
                                                     guint** blue,
                                                     gint* blue_length1,
                                                     GError** error);
VALA_EXTERN void mutter_display_config_interface_set_crtc_gamma (MutterDisplayConfigInterface* self,
                                                     guint serial,
                                                     guint crtc,
                                                     guint* red,
                                                     gint red_length1,
                                                     guint* green,
                                                     gint green_length1,
                                                     guint* blue,
                                                     gint blue_length1,
                                                     GError** error);
VALA_EXTERN void mutter_display_config_interface_get_current_state (MutterDisplayConfigInterface* self,
                                                        guint* serial,
                                                        MutterReadMonitor** monitors,
                                                        gint* monitors_length1,
                                                        MutterReadLogicalMonitor** logical_monitors,
                                                        gint* logical_monitors_length1,
                                                        GHashTable** properties,
                                                        GError** error);
VALA_EXTERN void mutter_display_config_interface_apply_monitors_config (MutterDisplayConfigInterface* self,
                                                            guint serial,
                                                            MutterApplyMethod method,
                                                            MutterWriteLogicalMonitor* logical_monitors,
                                                            gint logical_monitors_length1,
                                                            GHashTable* properties,
                                                            GError** error);
VALA_EXTERN gint mutter_display_config_interface_get_power_save_mode (MutterDisplayConfigInterface* self);
VALA_EXTERN void mutter_display_config_interface_set_power_save_mode (MutterDisplayConfigInterface* self,
                                                          gint value);
VALA_EXTERN gchar* display_transform_to_string (DisplayTransform self);
VALA_EXTERN guint mutter_read_monitor_info_get_hash (MutterReadMonitorInfo* self);
VALA_EXTERN GType display_sensor_proxy_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DisplaySensorProxy, g_object_unref)
VALA_EXTERN GType display_sensor_proxy_proxy_get_type (void) G_GNUC_CONST ;
VALA_EXTERN guint display_sensor_proxy_register_object (void* object,
                                            GDBusConnection* connection,
                                            const gchar* path,
                                            GError** error);
VALA_EXTERN gboolean display_sensor_proxy_get_has_accelerometer (DisplaySensorProxy* self);
VALA_EXTERN GType display_sensor_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DisplaySensorManager, g_object_unref)
VALA_EXTERN DisplaySensorManager* display_sensor_manager_get_default (void);
VALA_EXTERN gboolean display_sensor_manager_get_has_accelerometer (DisplaySensorManager* self);
VALA_EXTERN GType display_virtual_monitor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DisplayVirtualMonitor, g_object_unref)
VALA_EXTERN const gchar* display_virtual_monitor_get_display_name (DisplayVirtualMonitor* self);
VALA_EXTERN void display_virtual_monitor_get_current_mode_size (DisplayVirtualMonitor* self,
                                                    gint* width,
                                                    gint* height);
VALA_EXTERN GeeLinkedList* display_virtual_monitor_get_available_modes (DisplayVirtualMonitor* self);
VALA_EXTERN DisplayMonitorMode* display_virtual_monitor_get_mode_for_resolution (DisplayVirtualMonitor* self,
                                                                     gint width,
                                                                     gint height);
VALA_EXTERN void display_virtual_monitor_set_current_mode (DisplayVirtualMonitor* self,
                                               DisplayMonitorMode* current_mode);
VALA_EXTERN gchar* display_virtual_monitor_generate_id_from_monitors (MutterReadMonitorInfo* infos,
                                                          gint infos_length1);
VALA_EXTERN DisplayVirtualMonitor* display_virtual_monitor_new (void);
VALA_EXTERN DisplayVirtualMonitor* display_virtual_monitor_construct (GType object_type);
VALA_EXTERN gint display_virtual_monitor_get_x (DisplayVirtualMonitor* self);
VALA_EXTERN void display_virtual_monitor_set_x (DisplayVirtualMonitor* self,
                                    gint value);
VALA_EXTERN gint display_virtual_monitor_get_y (DisplayVirtualMonitor* self);
VALA_EXTERN void display_virtual_monitor_set_y (DisplayVirtualMonitor* self,
                                    gint value);
VALA_EXTERN gint display_virtual_monitor_get_current_x (DisplayVirtualMonitor* self);
VALA_EXTERN void display_virtual_monitor_set_current_x (DisplayVirtualMonitor* self,
                                            gint value);
VALA_EXTERN gint display_virtual_monitor_get_current_y (DisplayVirtualMonitor* self);
VALA_EXTERN void display_virtual_monitor_set_current_y (DisplayVirtualMonitor* self,
                                            gint value);
VALA_EXTERN GtkSingleSelection* display_virtual_monitor_get_available_scales (DisplayVirtualMonitor* self);
VALA_EXTERN GtkSingleSelection* display_virtual_monitor_get_available_transforms (DisplayVirtualMonitor* self);
VALA_EXTERN gboolean display_virtual_monitor_get_primary (DisplayVirtualMonitor* self);
VALA_EXTERN void display_virtual_monitor_set_primary (DisplayVirtualMonitor* self,
                                          gboolean value);
VALA_EXTERN GeeLinkedList* display_virtual_monitor_get_monitors (DisplayVirtualMonitor* self);
VALA_EXTERN gdouble display_virtual_monitor_get_scale (DisplayVirtualMonitor* self);
VALA_EXTERN void display_virtual_monitor_set_scale (DisplayVirtualMonitor* self,
                                        gdouble value);
VALA_EXTERN DisplayTransform display_virtual_monitor_get_transform (DisplayVirtualMonitor* self);
VALA_EXTERN void display_virtual_monitor_set_transform (DisplayVirtualMonitor* self,
                                            DisplayTransform value);
VALA_EXTERN gchar* display_virtual_monitor_get_id (DisplayVirtualMonitor* self);
VALA_EXTERN gboolean display_virtual_monitor_get_is_mirror (DisplayVirtualMonitor* self);
VALA_EXTERN gboolean display_virtual_monitor_get_is_active (DisplayVirtualMonitor* self);
VALA_EXTERN void display_virtual_monitor_set_is_active (DisplayVirtualMonitor* self,
                                            gboolean value);
VALA_EXTERN DisplayMonitor* display_virtual_monitor_get_monitor (DisplayVirtualMonitor* self);
VALA_EXTERN GType display_virtual_monitor_scale_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DisplayVirtualMonitorScale, g_object_unref)
VALA_EXTERN DisplayVirtualMonitorScale* display_virtual_monitor_scale_new (gdouble scale);
VALA_EXTERN DisplayVirtualMonitorScale* display_virtual_monitor_scale_construct (GType object_type,
                                                                     gdouble scale);
VALA_EXTERN gdouble display_virtual_monitor_scale_get_scale (DisplayVirtualMonitorScale* self);
VALA_EXTERN const gchar* display_virtual_monitor_scale_get_string_representation (DisplayVirtualMonitorScale* self);
VALA_EXTERN GType display_virtual_monitor_transform_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DisplayVirtualMonitorTransform, g_object_unref)
VALA_EXTERN DisplayVirtualMonitorTransform* display_virtual_monitor_transform_new (DisplayTransform transform);
VALA_EXTERN DisplayVirtualMonitorTransform* display_virtual_monitor_transform_construct (GType object_type,
                                                                             DisplayTransform transform);
VALA_EXTERN DisplayTransform display_virtual_monitor_transform_get_transform (DisplayVirtualMonitorTransform* self);
VALA_EXTERN const gchar* display_virtual_monitor_transform_get_string_representation (DisplayVirtualMonitorTransform* self);
VALA_EXTERN gint display_monitor_mode_resolution_compare_func (DisplayMonitorMode* a,
                                                   DisplayMonitorMode* b);
VALA_EXTERN const gchar* display_monitor_mode_get_resolution (DisplayMonitorMode* self);
VALA_EXTERN gchar* display_monitor_mode_get_resolution_string (gint width,
                                                   gint height,
                                                   gboolean include_aspect);
VALA_EXTERN DisplayMonitorMode* display_monitor_mode_new (void);
VALA_EXTERN DisplayMonitorMode* display_monitor_mode_construct (GType object_type);
VALA_EXTERN const gchar* display_monitor_mode_get_id (DisplayMonitorMode* self);
VALA_EXTERN void display_monitor_mode_set_id (DisplayMonitorMode* self,
                                  const gchar* value);
VALA_EXTERN gint display_monitor_mode_get_width (DisplayMonitorMode* self);
VALA_EXTERN void display_monitor_mode_set_width (DisplayMonitorMode* self,
                                     gint value);
VALA_EXTERN gint display_monitor_mode_get_height (DisplayMonitorMode* self);
VALA_EXTERN void display_monitor_mode_set_height (DisplayMonitorMode* self,
                                      gint value);
VALA_EXTERN gdouble display_monitor_mode_get_frequency (DisplayMonitorMode* self);
VALA_EXTERN void display_monitor_mode_set_frequency (DisplayMonitorMode* self,
                                         gdouble value);
VALA_EXTERN gdouble display_monitor_mode_get_preferred_scale (DisplayMonitorMode* self);
VALA_EXTERN void display_monitor_mode_set_preferred_scale (DisplayMonitorMode* self,
                                               gdouble value);
VALA_EXTERN gboolean display_monitor_mode_get_is_preferred (DisplayMonitorMode* self);
VALA_EXTERN void display_monitor_mode_set_is_preferred (DisplayMonitorMode* self,
                                            gboolean value);
VALA_EXTERN gboolean display_monitor_mode_get_is_current (DisplayMonitorMode* self);
VALA_EXTERN void display_monitor_mode_set_is_current (DisplayMonitorMode* self,
                                          gboolean value);
VALA_EXTERN GType display_monitor_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DisplayMonitorManager, g_object_unref)
VALA_EXTERN DisplayMonitorManager* display_monitor_manager_get_default (void);
VALA_EXTERN void display_monitor_manager_get_monitor_config (DisplayMonitorManager* self);
VALA_EXTERN void display_monitor_manager_set_monitor_config (DisplayMonitorManager* self,
                                                 GError** error);
VALA_EXTERN void display_monitor_manager_get_mutter_logical_monitor (DisplayVirtualMonitor* virtual_monitor,
                                                         MutterWriteLogicalMonitor* result);
VALA_EXTERN void display_monitor_manager_enable_clone_mode (DisplayMonitorManager* self);
VALA_EXTERN void display_monitor_manager_set_scale_on_all_monitors (DisplayMonitorManager* self,
                                                        gdouble new_scale,
                                                        GError** error);
VALA_EXTERN void display_monitor_manager_disable_clone_mode (DisplayMonitorManager* self);
VALA_EXTERN GeeLinkedList* display_monitor_manager_get_virtual_monitors (DisplayMonitorManager* self);
VALA_EXTERN GeeLinkedList* display_monitor_manager_get_monitors (DisplayMonitorManager* self);
VALA_EXTERN gboolean display_monitor_manager_get_fractional_scale_enabled (DisplayMonitorManager* self);
VALA_EXTERN gboolean display_monitor_manager_get_global_scale_required (DisplayMonitorManager* self);
VALA_EXTERN gboolean display_monitor_manager_get_mirroring_supported (DisplayMonitorManager* self);
VALA_EXTERN gint display_monitor_manager_get_max_width (DisplayMonitorManager* self);
VALA_EXTERN gint display_monitor_manager_get_max_height (DisplayMonitorManager* self);
VALA_EXTERN gint display_monitor_manager_get_monitor_number (DisplayMonitorManager* self);
VALA_EXTERN gint display_monitor_manager_get_virtual_monitor_number (DisplayMonitorManager* self);
VALA_EXTERN gboolean display_monitor_manager_get_is_mirrored (DisplayMonitorManager* self);
VALA_EXTERN gdouble display_monitor_get_max_scale (DisplayMonitor* self);
VALA_EXTERN DisplayMonitorMode* display_monitor_get_mode_by_id (DisplayMonitor* self,
                                                    const gchar* id);
VALA_EXTERN DisplayMonitor* display_monitor_new (void);
VALA_EXTERN DisplayMonitor* display_monitor_construct (GType object_type);
VALA_EXTERN const gchar* display_monitor_get_connector (DisplayMonitor* self);
VALA_EXTERN void display_monitor_set_connector (DisplayMonitor* self,
                                    const gchar* value);
VALA_EXTERN const gchar* display_monitor_get_vendor (DisplayMonitor* self);
VALA_EXTERN void display_monitor_set_vendor (DisplayMonitor* self,
                                 const gchar* value);
VALA_EXTERN const gchar* display_monitor_get_product (DisplayMonitor* self);
VALA_EXTERN void display_monitor_set_product (DisplayMonitor* self,
                                  const gchar* value);
VALA_EXTERN const gchar* display_monitor_get_serial (DisplayMonitor* self);
VALA_EXTERN void display_monitor_set_serial (DisplayMonitor* self,
                                 const gchar* value);
VALA_EXTERN guint display_monitor_get_hash (DisplayMonitor* self);
VALA_EXTERN const gchar* display_monitor_get_display_name (DisplayMonitor* self);
VALA_EXTERN void display_monitor_set_display_name (DisplayMonitor* self,
                                       const gchar* value);
VALA_EXTERN gboolean display_monitor_get_is_builtin (DisplayMonitor* self);
VALA_EXTERN void display_monitor_set_is_builtin (DisplayMonitor* self,
                                     gboolean value);
VALA_EXTERN GeeLinkedList* display_monitor_get_modes (DisplayMonitor* self);
VALA_EXTERN DisplayMonitorMode* display_monitor_get_current_mode (DisplayMonitor* self);
VALA_EXTERN DisplayMonitorMode* display_monitor_get_preferred_mode (DisplayMonitor* self);
VALA_EXTERN GType display_night_light_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DisplayNightLightView, g_object_unref)
VALA_EXTERN DisplayNightLightView* display_night_light_view_new (void);
VALA_EXTERN DisplayNightLightView* display_night_light_view_construct (GType object_type);
VALA_EXTERN GType display_displays_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DisplayDisplaysView, g_object_unref)
VALA_EXTERN GType display_displays_overlay_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DisplayDisplaysOverlay, g_object_unref)
VALA_EXTERN DisplayDisplaysView* display_displays_view_new (void);
VALA_EXTERN DisplayDisplaysView* display_displays_view_construct (GType object_type);
VALA_EXTERN GType display_filters_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DisplayFiltersView, g_object_unref)
VALA_EXTERN DisplayFiltersView* display_filters_view_new (void);
VALA_EXTERN DisplayFiltersView* display_filters_view_construct (GType object_type);
VALA_EXTERN GType display_resolution_get_type (void) G_GNUC_CONST ;
VALA_EXTERN DisplayResolution* display_resolution_dup (const DisplayResolution* self);
VALA_EXTERN void display_resolution_free (DisplayResolution* self);
VALA_EXTERN GType display_display_widget_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DisplayDisplayWidget, g_object_unref)
VALA_EXTERN DisplayDisplayWidget* display_display_widget_new (DisplayVirtualMonitor* virtual_monitor,
                                                  const gchar* bg_color,
                                                  const gchar* text_color);
VALA_EXTERN DisplayDisplayWidget* display_display_widget_construct (GType object_type,
                                                        DisplayVirtualMonitor* virtual_monitor,
                                                        const gchar* bg_color,
                                                        const gchar* text_color);
VALA_EXTERN void display_display_widget_set_primary (DisplayDisplayWidget* self,
                                         gboolean is_primary);
VALA_EXTERN void display_display_widget_get_preferred_size (DisplayDisplayWidget* self,
                                                GtkRequisition* minimum_size,
                                                GtkRequisition* natural_size);
VALA_EXTERN void display_display_widget_get_virtual_monitor_geometry (DisplayDisplayWidget* self,
                                                          gint* x,
                                                          gint* y,
                                                          gint* width,
                                                          gint* height);
VALA_EXTERN void display_display_widget_set_virtual_monitor_geometry (DisplayDisplayWidget* self,
                                                          gint x,
                                                          gint y,
                                                          gint width,
                                                          gint height);
VALA_EXTERN void display_display_widget_move_x (DisplayDisplayWidget* self,
                                    gint dx);
VALA_EXTERN void display_display_widget_move_y (DisplayDisplayWidget* self,
                                    gint dy);
VALA_EXTERN gboolean display_display_widget_equals (DisplayDisplayWidget* self,
                                        DisplayDisplayWidget* sibling);
VALA_EXTERN DisplayVirtualMonitor* display_display_widget_get_virtual_monitor (DisplayDisplayWidget* self);
VALA_EXTERN const gchar* display_display_widget_get_bg_color (DisplayDisplayWidget* self);
VALA_EXTERN const gchar* display_display_widget_get_text_color (DisplayDisplayWidget* self);
VALA_EXTERN const gchar* display_display_widget_get_display_name (DisplayDisplayWidget* self);
VALA_EXTERN gdouble display_display_widget_get_window_ratio (DisplayDisplayWidget* self);
VALA_EXTERN gboolean display_display_widget_get_connected (DisplayDisplayWidget* self);
VALA_EXTERN void display_display_widget_set_connected (DisplayDisplayWidget* self,
                                           gboolean value);
VALA_EXTERN void display_displays_overlay_rescan_displays (DisplayDisplaysOverlay* self);
VALA_EXTERN void display_displays_overlay_show_windows (DisplayDisplaysOverlay* self);
VALA_EXTERN void display_displays_overlay_hide_windows (DisplayDisplaysOverlay* self);
VALA_EXTERN DisplayDisplaysOverlay* display_displays_overlay_new (void);
VALA_EXTERN DisplayDisplaysOverlay* display_displays_overlay_construct (GType object_type);
VALA_EXTERN gint display_displays_overlay_get_active_displays (DisplayDisplaysOverlay* self);
VALA_EXTERN void display_displays_overlay_set_active_displays (DisplayDisplaysOverlay* self,
                                                   gint value);
VALA_EXTERN gboolean display_displays_overlay_get_only_display (DisplayDisplaysOverlay* self);

G_END_DECLS

#endif
