/* FiltersView.c generated by valac 0.56.19, the Vala compiler
 * generated from FiltersView.vala, do not modify */

/*
 * SPDX-License-Identifier: LGPL-2.0-or-later
 * SPDX-FileCopyrightText: 2023 elementary, Inc. (https://elementary.io)
 */

#include "display.h"
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <granite-7.h>
#include <glib/gi18n-lib.h>
#include <float.h>
#include <math.h>
#include <adwaita.h>
#include <gio/gio.h>

#define DISPLAY_FILTERS_VIEW_TEXT_MARKUP "%s\n<span size='smaller' alpha='75%'>%s</span>"
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

enum  {
	DISPLAY_FILTERS_VIEW_0_PROPERTY,
	DISPLAY_FILTERS_VIEW_NUM_PROPERTIES
};
static GParamSpec* display_filters_view_properties[DISPLAY_FILTERS_VIEW_NUM_PROPERTIES];

#define DISPLAY_FILTERS_VIEW_TYPE_COLOR_SWATCH (display_filters_view_color_swatch_get_type ())
#define DISPLAY_FILTERS_VIEW_COLOR_SWATCH(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), DISPLAY_FILTERS_VIEW_TYPE_COLOR_SWATCH, DisplayFiltersViewColorSwatch))
#define DISPLAY_FILTERS_VIEW_COLOR_SWATCH_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), DISPLAY_FILTERS_VIEW_TYPE_COLOR_SWATCH, DisplayFiltersViewColorSwatchClass))
#define DISPLAY_FILTERS_VIEW_IS_COLOR_SWATCH(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), DISPLAY_FILTERS_VIEW_TYPE_COLOR_SWATCH))
#define DISPLAY_FILTERS_VIEW_IS_COLOR_SWATCH_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), DISPLAY_FILTERS_VIEW_TYPE_COLOR_SWATCH))
#define DISPLAY_FILTERS_VIEW_COLOR_SWATCH_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), DISPLAY_FILTERS_VIEW_TYPE_COLOR_SWATCH, DisplayFiltersViewColorSwatchClass))

typedef struct _DisplayFiltersViewColorSwatch DisplayFiltersViewColorSwatch;
typedef struct _DisplayFiltersViewColorSwatchClass DisplayFiltersViewColorSwatchClass;
typedef struct _DisplayFiltersViewColorSwatchPrivate DisplayFiltersViewColorSwatchPrivate;
enum  {
	DISPLAY_FILTERS_VIEW_COLOR_SWATCH_0_PROPERTY,
	DISPLAY_FILTERS_VIEW_COLOR_SWATCH_COLOR_PROPERTY,
	DISPLAY_FILTERS_VIEW_COLOR_SWATCH_NUM_PROPERTIES
};
static GParamSpec* display_filters_view_color_swatch_properties[DISPLAY_FILTERS_VIEW_COLOR_SWATCH_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _DisplayFiltersViewColorSwatch {
	GtkGrid parent_instance;
	DisplayFiltersViewColorSwatchPrivate * priv;
};

struct _DisplayFiltersViewColorSwatchClass {
	GtkGridClass parent_class;
};

struct _DisplayFiltersViewColorSwatchPrivate {
	gchar* _color;
};

static gpointer display_filters_view_parent_class = NULL;
static gint DisplayFiltersViewColorSwatch_private_offset;
static gpointer display_filters_view_color_swatch_parent_class = NULL;
static GtkCssProvider* display_filters_view_color_swatch_provider;
static GtkCssProvider* display_filters_view_color_swatch_provider = NULL;

static GType display_filters_view_color_swatch_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
static DisplayFiltersViewColorSwatch* display_filters_view_color_swatch_new (const gchar* color);
static DisplayFiltersViewColorSwatch* display_filters_view_color_swatch_construct (GType object_type,
                                                                            const gchar* color);
static const gchar* display_filters_view_color_swatch_get_color (DisplayFiltersViewColorSwatch* self);
static void display_filters_view_color_swatch_set_color (DisplayFiltersViewColorSwatch* self,
                                                  const gchar* value);
static GObject * display_filters_view_color_swatch_constructor (GType type,
                                                         guint n_construct_properties,
                                                         GObjectConstructParam * construct_properties);
static void display_filters_view_color_swatch_finalize (GObject * obj);
static GType display_filters_view_color_swatch_get_type_once (void);
static void _vala_display_filters_view_color_swatch_get_property (GObject * object,
                                                           guint property_id,
                                                           GValue * value,
                                                           GParamSpec * pspec);
static void _vala_display_filters_view_color_swatch_set_property (GObject * object,
                                                           guint property_id,
                                                           const GValue * value,
                                                           GParamSpec * pspec);
static GObject * display_filters_view_constructor (GType type,
                                            guint n_construct_properties,
                                            GObjectConstructParam * construct_properties);
static gboolean _display_filters_view___lambda31_ (GValue* value,
                                            GVariant* variant,
                                            void* user_data);
static gboolean __display_filters_view___lambda31__gsettings_bind_get_mapping (GValue* value,
                                                                        GVariant* variant,
                                                                        void* user_data);
static GVariant* _display_filters_view___lambda32_ (GValue* value,
                                             const GVariantType* expected_type,
                                             void* user_data);
static GVariant* __display_filters_view___lambda32__gsettings_bind_set_mapping (GValue* value,
                                                                         const GVariantType* expected_type,
                                                                         void* user_data);
static gboolean _display_filters_view___lambda33_ (GValue* value,
                                            GVariant* variant,
                                            void* user_data);
static gboolean __display_filters_view___lambda33__gsettings_bind_get_mapping (GValue* value,
                                                                        GVariant* variant,
                                                                        void* user_data);
static GVariant* _display_filters_view___lambda34_ (GValue* value,
                                             const GVariantType* expected_type,
                                             void* user_data);
static GVariant* __display_filters_view___lambda34__gsettings_bind_set_mapping (GValue* value,
                                                                         const GVariantType* expected_type,
                                                                         void* user_data);
static gboolean _display_filters_view___lambda35_ (GValue* value,
                                            GVariant* variant,
                                            void* user_data);
static gboolean __display_filters_view___lambda35__gsettings_bind_get_mapping (GValue* value,
                                                                        GVariant* variant,
                                                                        void* user_data);
static GVariant* _display_filters_view___lambda36_ (GValue* value,
                                             const GVariantType* expected_type,
                                             void* user_data);
static GVariant* __display_filters_view___lambda36__gsettings_bind_set_mapping (GValue* value,
                                                                         const GVariantType* expected_type,
                                                                         void* user_data);
static gboolean _display_filters_view___lambda37_ (GValue* value,
                                            GVariant* variant,
                                            void* user_data);
static gboolean __display_filters_view___lambda37__gsettings_bind_get_mapping (GValue* value,
                                                                        GVariant* variant,
                                                                        void* user_data);
static GVariant* _display_filters_view___lambda38_ (GValue* value,
                                             const GVariantType* expected_type,
                                             void* user_data);
static GVariant* __display_filters_view___lambda38__gsettings_bind_set_mapping (GValue* value,
                                                                         const GVariantType* expected_type,
                                                                         void* user_data);
static gboolean _display_filters_view___lambda39_ (GValue* value,
                                            GVariant* variant,
                                            void* user_data);
static gboolean __display_filters_view___lambda39__gsettings_bind_get_mapping (GValue* value,
                                                                        GVariant* variant,
                                                                        void* user_data);
static GVariant* _display_filters_view___lambda40_ (GValue* value,
                                             const GVariantType* expected_type,
                                             void* user_data);
static GVariant* __display_filters_view___lambda40__gsettings_bind_set_mapping (GValue* value,
                                                                         const GVariantType* expected_type,
                                                                         void* user_data);
static gboolean _display_filters_view___lambda41_ (GValue* value,
                                            GVariant* variant,
                                            void* user_data);
static gboolean __display_filters_view___lambda41__gsettings_bind_get_mapping (GValue* value,
                                                                        GVariant* variant,
                                                                        void* user_data);
static GVariant* _display_filters_view___lambda42_ (GValue* value,
                                             const GVariantType* expected_type,
                                             void* user_data);
static GVariant* __display_filters_view___lambda42__gsettings_bind_set_mapping (GValue* value,
                                                                         const GVariantType* expected_type,
                                                                         void* user_data);
static gboolean _display_filters_view___lambda43_ (GValue* value,
                                            GVariant* variant,
                                            void* user_data);
static gboolean __display_filters_view___lambda43__gsettings_bind_get_mapping (GValue* value,
                                                                        GVariant* variant,
                                                                        void* user_data);
static GVariant* _display_filters_view___lambda44_ (GValue* value,
                                             const GVariantType* expected_type,
                                             void* user_data);
static GVariant* __display_filters_view___lambda44__gsettings_bind_set_mapping (GValue* value,
                                                                         const GVariantType* expected_type,
                                                                         void* user_data);
static GType display_filters_view_get_type_once (void);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

DisplayFiltersView*
display_filters_view_construct (GType object_type)
{
	DisplayFiltersView * self = NULL;
	self = (DisplayFiltersView*) g_object_new (object_type, NULL);
	return self;
}

DisplayFiltersView*
display_filters_view_new (void)
{
	return display_filters_view_construct (DISPLAY_TYPE_FILTERS_VIEW);
}

static inline gpointer
display_filters_view_color_swatch_get_instance_private (DisplayFiltersViewColorSwatch* self)
{
	return G_STRUCT_MEMBER_P (self, DisplayFiltersViewColorSwatch_private_offset);
}

static DisplayFiltersViewColorSwatch*
display_filters_view_color_swatch_construct (GType object_type,
                                             const gchar* color)
{
	DisplayFiltersViewColorSwatch * self = NULL;
	g_return_val_if_fail (color != NULL, NULL);
	self = (DisplayFiltersViewColorSwatch*) g_object_new (object_type, "color", color, NULL);
	return self;
}

static DisplayFiltersViewColorSwatch*
display_filters_view_color_swatch_new (const gchar* color)
{
	return display_filters_view_color_swatch_construct (DISPLAY_FILTERS_VIEW_TYPE_COLOR_SWATCH, color);
}

static const gchar*
display_filters_view_color_swatch_get_color (DisplayFiltersViewColorSwatch* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_color;
	result = _tmp0_;
	return result;
}

static void
display_filters_view_color_swatch_set_color (DisplayFiltersViewColorSwatch* self,
                                             const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = display_filters_view_color_swatch_get_color (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_color);
		self->priv->_color = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, display_filters_view_color_swatch_properties[DISPLAY_FILTERS_VIEW_COLOR_SWATCH_COLOR_PROPERTY]);
	}
}

static GObject *
display_filters_view_color_swatch_constructor (GType type,
                                               guint n_construct_properties,
                                               GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	DisplayFiltersViewColorSwatch * self;
	GtkStyleContext* _tmp0_;
	GtkCssProvider* _tmp1_;
	const gchar* _tmp2_;
	parent_class = G_OBJECT_CLASS (display_filters_view_color_swatch_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DISPLAY_FILTERS_VIEW_TYPE_COLOR_SWATCH, DisplayFiltersViewColorSwatch);
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
	_tmp1_ = display_filters_view_color_swatch_provider;
	gtk_style_context_add_provider (_tmp0_, (GtkStyleProvider*) _tmp1_, (guint) GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
	_tmp2_ = self->priv->_color;
	gtk_widget_add_css_class ((GtkWidget*) self, _tmp2_);
	gtk_widget_set_valign ((GtkWidget*) self, GTK_ALIGN_CENTER);
	return obj;
}

static void
display_filters_view_color_swatch_base_init (DisplayFiltersViewColorSwatchClass * klass)
{
	gtk_widget_class_set_css_name (GTK_WIDGET_CLASS (klass), "colorswatch");
}

static void
display_filters_view_color_swatch_class_init (DisplayFiltersViewColorSwatchClass * klass,
                                              gpointer klass_data)
{
	GtkCssProvider* _tmp0_;
	GtkCssProvider* _tmp1_;
	display_filters_view_color_swatch_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &DisplayFiltersViewColorSwatch_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_display_filters_view_color_swatch_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_display_filters_view_color_swatch_set_property;
	G_OBJECT_CLASS (klass)->constructor = display_filters_view_color_swatch_constructor;
	G_OBJECT_CLASS (klass)->finalize = display_filters_view_color_swatch_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), DISPLAY_FILTERS_VIEW_COLOR_SWATCH_COLOR_PROPERTY, display_filters_view_color_swatch_properties[DISPLAY_FILTERS_VIEW_COLOR_SWATCH_COLOR_PROPERTY] = g_param_spec_string ("color", "color", "color", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
	_tmp0_ = gtk_css_provider_new ();
	_g_object_unref0 (display_filters_view_color_swatch_provider);
	display_filters_view_color_swatch_provider = _tmp0_;
	_tmp1_ = display_filters_view_color_swatch_provider;
	gtk_css_provider_load_from_resource (_tmp1_, "io/elementary/settings/display/Filters.css");
}

static void
display_filters_view_color_swatch_instance_init (DisplayFiltersViewColorSwatch * self,
                                                 gpointer klass)
{
	self->priv = display_filters_view_color_swatch_get_instance_private (self);
}

static void
display_filters_view_color_swatch_finalize (GObject * obj)
{
	DisplayFiltersViewColorSwatch * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DISPLAY_FILTERS_VIEW_TYPE_COLOR_SWATCH, DisplayFiltersViewColorSwatch);
	_g_free0 (self->priv->_color);
	G_OBJECT_CLASS (display_filters_view_color_swatch_parent_class)->finalize (obj);
}

static GType
display_filters_view_color_swatch_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (DisplayFiltersViewColorSwatchClass), (GBaseInitFunc) display_filters_view_color_swatch_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) display_filters_view_color_swatch_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DisplayFiltersViewColorSwatch), 0, (GInstanceInitFunc) display_filters_view_color_swatch_instance_init, NULL };
	GType display_filters_view_color_swatch_type_id;
	display_filters_view_color_swatch_type_id = g_type_register_static (gtk_grid_get_type (), "DisplayFiltersViewColorSwatch", &g_define_type_info, 0);
	DisplayFiltersViewColorSwatch_private_offset = g_type_add_instance_private (display_filters_view_color_swatch_type_id, sizeof (DisplayFiltersViewColorSwatchPrivate));
	return display_filters_view_color_swatch_type_id;
}

static GType
display_filters_view_color_swatch_get_type (void)
{
	static volatile gsize display_filters_view_color_swatch_type_id__once = 0;
	if (g_once_init_enter (&display_filters_view_color_swatch_type_id__once)) {
		GType display_filters_view_color_swatch_type_id;
		display_filters_view_color_swatch_type_id = display_filters_view_color_swatch_get_type_once ();
		g_once_init_leave (&display_filters_view_color_swatch_type_id__once, display_filters_view_color_swatch_type_id);
	}
	return display_filters_view_color_swatch_type_id__once;
}

static void
_vala_display_filters_view_color_swatch_get_property (GObject * object,
                                                      guint property_id,
                                                      GValue * value,
                                                      GParamSpec * pspec)
{
	DisplayFiltersViewColorSwatch * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, DISPLAY_FILTERS_VIEW_TYPE_COLOR_SWATCH, DisplayFiltersViewColorSwatch);
	switch (property_id) {
		case DISPLAY_FILTERS_VIEW_COLOR_SWATCH_COLOR_PROPERTY:
		g_value_set_string (value, display_filters_view_color_swatch_get_color (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_display_filters_view_color_swatch_set_property (GObject * object,
                                                      guint property_id,
                                                      const GValue * value,
                                                      GParamSpec * pspec)
{
	DisplayFiltersViewColorSwatch * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, DISPLAY_FILTERS_VIEW_TYPE_COLOR_SWATCH, DisplayFiltersViewColorSwatch);
	switch (property_id) {
		case DISPLAY_FILTERS_VIEW_COLOR_SWATCH_COLOR_PROPERTY:
		display_filters_view_color_swatch_set_color (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static gboolean
_display_filters_view___lambda31_ (GValue* value,
                                   GVariant* variant,
                                   void* user_data)
{
	const gchar* _tmp0_;
	gboolean result;
	g_return_val_if_fail (value != NULL, FALSE);
	g_return_val_if_fail (variant != NULL, FALSE);
	_tmp0_ = g_variant_get_string (variant, NULL);
	g_value_set_boolean (value, g_strcmp0 (_tmp0_, "none") == 0);
	result = TRUE;
	return result;
}

static gboolean
__display_filters_view___lambda31__gsettings_bind_get_mapping (GValue* value,
                                                               GVariant* variant,
                                                               void* user_data)
{
	gboolean result;
	result = _display_filters_view___lambda31_ (value, variant, user_data);
	return result;
}

static GVariant*
_display_filters_view___lambda32_ (GValue* value,
                                   const GVariantType* expected_type,
                                   void* user_data)
{
	GVariant* result;
	g_return_val_if_fail (value != NULL, NULL);
	g_return_val_if_fail (expected_type != NULL, NULL);
	if (g_value_get_boolean (value)) {
		GVariant* _tmp0_;
		_tmp0_ = g_variant_new ("s", "none", NULL);
		g_variant_ref_sink (_tmp0_);
		result = _tmp0_;
		return result;
	}
	result = NULL;
	return result;
}

static GVariant*
__display_filters_view___lambda32__gsettings_bind_set_mapping (GValue* value,
                                                               const GVariantType* expected_type,
                                                               void* user_data)
{
	GVariant* result;
	result = _display_filters_view___lambda32_ (value, expected_type, user_data);
	return result;
}

static gboolean
_display_filters_view___lambda33_ (GValue* value,
                                   GVariant* variant,
                                   void* user_data)
{
	const gchar* _tmp0_;
	gboolean result;
	g_return_val_if_fail (value != NULL, FALSE);
	g_return_val_if_fail (variant != NULL, FALSE);
	_tmp0_ = g_variant_get_string (variant, NULL);
	g_value_set_boolean (value, g_strcmp0 (_tmp0_, "protanopia") == 0);
	result = TRUE;
	return result;
}

static gboolean
__display_filters_view___lambda33__gsettings_bind_get_mapping (GValue* value,
                                                               GVariant* variant,
                                                               void* user_data)
{
	gboolean result;
	result = _display_filters_view___lambda33_ (value, variant, user_data);
	return result;
}

static GVariant*
_display_filters_view___lambda34_ (GValue* value,
                                   const GVariantType* expected_type,
                                   void* user_data)
{
	GVariant* result;
	g_return_val_if_fail (value != NULL, NULL);
	g_return_val_if_fail (expected_type != NULL, NULL);
	if (g_value_get_boolean (value)) {
		GVariant* _tmp0_;
		_tmp0_ = g_variant_new ("s", "protanopia", NULL);
		g_variant_ref_sink (_tmp0_);
		result = _tmp0_;
		return result;
	}
	result = NULL;
	return result;
}

static GVariant*
__display_filters_view___lambda34__gsettings_bind_set_mapping (GValue* value,
                                                               const GVariantType* expected_type,
                                                               void* user_data)
{
	GVariant* result;
	result = _display_filters_view___lambda34_ (value, expected_type, user_data);
	return result;
}

static gboolean
_display_filters_view___lambda35_ (GValue* value,
                                   GVariant* variant,
                                   void* user_data)
{
	const gchar* _tmp0_;
	gboolean result;
	g_return_val_if_fail (value != NULL, FALSE);
	g_return_val_if_fail (variant != NULL, FALSE);
	_tmp0_ = g_variant_get_string (variant, NULL);
	g_value_set_boolean (value, g_strcmp0 (_tmp0_, "protanopia-high-contrast") == 0);
	result = TRUE;
	return result;
}

static gboolean
__display_filters_view___lambda35__gsettings_bind_get_mapping (GValue* value,
                                                               GVariant* variant,
                                                               void* user_data)
{
	gboolean result;
	result = _display_filters_view___lambda35_ (value, variant, user_data);
	return result;
}

static GVariant*
_display_filters_view___lambda36_ (GValue* value,
                                   const GVariantType* expected_type,
                                   void* user_data)
{
	GVariant* result;
	g_return_val_if_fail (value != NULL, NULL);
	g_return_val_if_fail (expected_type != NULL, NULL);
	if (g_value_get_boolean (value)) {
		GVariant* _tmp0_;
		_tmp0_ = g_variant_new ("s", "protanopia-high-contrast", NULL);
		g_variant_ref_sink (_tmp0_);
		result = _tmp0_;
		return result;
	}
	result = NULL;
	return result;
}

static GVariant*
__display_filters_view___lambda36__gsettings_bind_set_mapping (GValue* value,
                                                               const GVariantType* expected_type,
                                                               void* user_data)
{
	GVariant* result;
	result = _display_filters_view___lambda36_ (value, expected_type, user_data);
	return result;
}

static gboolean
_display_filters_view___lambda37_ (GValue* value,
                                   GVariant* variant,
                                   void* user_data)
{
	const gchar* _tmp0_;
	gboolean result;
	g_return_val_if_fail (value != NULL, FALSE);
	g_return_val_if_fail (variant != NULL, FALSE);
	_tmp0_ = g_variant_get_string (variant, NULL);
	g_value_set_boolean (value, g_strcmp0 (_tmp0_, "deuteranopia") == 0);
	result = TRUE;
	return result;
}

static gboolean
__display_filters_view___lambda37__gsettings_bind_get_mapping (GValue* value,
                                                               GVariant* variant,
                                                               void* user_data)
{
	gboolean result;
	result = _display_filters_view___lambda37_ (value, variant, user_data);
	return result;
}

static GVariant*
_display_filters_view___lambda38_ (GValue* value,
                                   const GVariantType* expected_type,
                                   void* user_data)
{
	GVariant* result;
	g_return_val_if_fail (value != NULL, NULL);
	g_return_val_if_fail (expected_type != NULL, NULL);
	if (g_value_get_boolean (value)) {
		GVariant* _tmp0_;
		_tmp0_ = g_variant_new ("s", "deuteranopia", NULL);
		g_variant_ref_sink (_tmp0_);
		result = _tmp0_;
		return result;
	}
	result = NULL;
	return result;
}

static GVariant*
__display_filters_view___lambda38__gsettings_bind_set_mapping (GValue* value,
                                                               const GVariantType* expected_type,
                                                               void* user_data)
{
	GVariant* result;
	result = _display_filters_view___lambda38_ (value, expected_type, user_data);
	return result;
}

static gboolean
_display_filters_view___lambda39_ (GValue* value,
                                   GVariant* variant,
                                   void* user_data)
{
	const gchar* _tmp0_;
	gboolean result;
	g_return_val_if_fail (value != NULL, FALSE);
	g_return_val_if_fail (variant != NULL, FALSE);
	_tmp0_ = g_variant_get_string (variant, NULL);
	g_value_set_boolean (value, g_strcmp0 (_tmp0_, "deuteranopia-high-contrast") == 0);
	result = TRUE;
	return result;
}

static gboolean
__display_filters_view___lambda39__gsettings_bind_get_mapping (GValue* value,
                                                               GVariant* variant,
                                                               void* user_data)
{
	gboolean result;
	result = _display_filters_view___lambda39_ (value, variant, user_data);
	return result;
}

static GVariant*
_display_filters_view___lambda40_ (GValue* value,
                                   const GVariantType* expected_type,
                                   void* user_data)
{
	GVariant* result;
	g_return_val_if_fail (value != NULL, NULL);
	g_return_val_if_fail (expected_type != NULL, NULL);
	if (g_value_get_boolean (value)) {
		GVariant* _tmp0_;
		_tmp0_ = g_variant_new ("s", "deuteranopia-high-contrast", NULL);
		g_variant_ref_sink (_tmp0_);
		result = _tmp0_;
		return result;
	}
	result = NULL;
	return result;
}

static GVariant*
__display_filters_view___lambda40__gsettings_bind_set_mapping (GValue* value,
                                                               const GVariantType* expected_type,
                                                               void* user_data)
{
	GVariant* result;
	result = _display_filters_view___lambda40_ (value, expected_type, user_data);
	return result;
}

static gboolean
_display_filters_view___lambda41_ (GValue* value,
                                   GVariant* variant,
                                   void* user_data)
{
	const gchar* _tmp0_;
	gboolean result;
	g_return_val_if_fail (value != NULL, FALSE);
	g_return_val_if_fail (variant != NULL, FALSE);
	_tmp0_ = g_variant_get_string (variant, NULL);
	g_value_set_boolean (value, g_strcmp0 (_tmp0_, "tritanopia") == 0);
	result = TRUE;
	return result;
}

static gboolean
__display_filters_view___lambda41__gsettings_bind_get_mapping (GValue* value,
                                                               GVariant* variant,
                                                               void* user_data)
{
	gboolean result;
	result = _display_filters_view___lambda41_ (value, variant, user_data);
	return result;
}

static GVariant*
_display_filters_view___lambda42_ (GValue* value,
                                   const GVariantType* expected_type,
                                   void* user_data)
{
	GVariant* result;
	g_return_val_if_fail (value != NULL, NULL);
	g_return_val_if_fail (expected_type != NULL, NULL);
	if (g_value_get_boolean (value)) {
		GVariant* _tmp0_;
		_tmp0_ = g_variant_new ("s", "tritanopia", NULL);
		g_variant_ref_sink (_tmp0_);
		result = _tmp0_;
		return result;
	}
	result = NULL;
	return result;
}

static GVariant*
__display_filters_view___lambda42__gsettings_bind_set_mapping (GValue* value,
                                                               const GVariantType* expected_type,
                                                               void* user_data)
{
	GVariant* result;
	result = _display_filters_view___lambda42_ (value, expected_type, user_data);
	return result;
}

static gboolean
_display_filters_view___lambda43_ (GValue* value,
                                   GVariant* variant,
                                   void* user_data)
{
	const gchar* _tmp0_;
	gboolean result;
	g_return_val_if_fail (value != NULL, FALSE);
	g_return_val_if_fail (variant != NULL, FALSE);
	_tmp0_ = g_variant_get_string (variant, NULL);
	g_value_set_boolean (value, g_strcmp0 (_tmp0_, "none") != 0);
	result = TRUE;
	return result;
}

static gboolean
__display_filters_view___lambda43__gsettings_bind_get_mapping (GValue* value,
                                                               GVariant* variant,
                                                               void* user_data)
{
	gboolean result;
	result = _display_filters_view___lambda43_ (value, variant, user_data);
	return result;
}

static GVariant*
_display_filters_view___lambda44_ (GValue* value,
                                   const GVariantType* expected_type,
                                   void* user_data)
{
	GVariant* result;
	g_return_val_if_fail (value != NULL, NULL);
	g_return_val_if_fail (expected_type != NULL, NULL);
	if (g_value_get_boolean (value)) {
		GVariant* _tmp0_;
		_tmp0_ = g_variant_new ("s", "none", NULL);
		g_variant_ref_sink (_tmp0_);
		result = _tmp0_;
		return result;
	}
	result = NULL;
	return result;
}

static GVariant*
__display_filters_view___lambda44__gsettings_bind_set_mapping (GValue* value,
                                                               const GVariantType* expected_type,
                                                               void* user_data)
{
	GVariant* result;
	result = _display_filters_view___lambda44_ (value, expected_type, user_data);
	return result;
}

static GObject *
display_filters_view_constructor (GType type,
                                  guint n_construct_properties,
                                  GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	DisplayFiltersView * self;
	GraniteHeaderLabel* colorblindness_header = NULL;
	gchar* _tmp0_;
	GraniteHeaderLabel* _tmp1_ = NULL;
	GtkCheckButton* none_radio = NULL;
	GtkCheckButton* _tmp2_;
	GtkLabel* protanopia_label = NULL;
	gchar* _tmp3_;
	gchar* _tmp4_;
	GtkLabel* _tmp5_ = NULL;
	GtkLabel* _tmp6_;
	GtkBox* protanopia_box = NULL;
	GtkBox* _tmp7_;
	GtkBox* _tmp8_;
	GtkLabel* _tmp9_;
	GtkBox* _tmp10_;
	DisplayFiltersViewColorSwatch* _tmp11_;
	DisplayFiltersViewColorSwatch* _tmp12_;
	GtkBox* _tmp13_;
	DisplayFiltersViewColorSwatch* _tmp14_;
	DisplayFiltersViewColorSwatch* _tmp15_;
	GtkBox* _tmp16_;
	DisplayFiltersViewColorSwatch* _tmp17_;
	DisplayFiltersViewColorSwatch* _tmp18_;
	GtkCheckButton* protanopia_radio = NULL;
	GtkCheckButton* _tmp19_;
	GtkCheckButton* _tmp20_;
	GtkCheckButton* _tmp21_ = NULL;
	GtkBox* _tmp22_;
	GtkCheckButton* _tmp23_;
	GtkLabel* protanopia_hc_label = NULL;
	gchar* _tmp24_;
	gchar* _tmp25_;
	GtkLabel* _tmp26_ = NULL;
	GtkLabel* _tmp27_;
	GtkBox* protanopia_hc_box = NULL;
	GtkBox* _tmp28_;
	GtkBox* _tmp29_;
	GtkLabel* _tmp30_;
	GtkCheckButton* protanopia_hc_radio = NULL;
	GtkCheckButton* _tmp31_;
	GtkCheckButton* _tmp32_;
	GtkCheckButton* _tmp33_ = NULL;
	GtkBox* _tmp34_;
	GtkCheckButton* _tmp35_;
	GtkLabel* deuteranopia_label = NULL;
	gchar* _tmp36_;
	gchar* _tmp37_;
	GtkLabel* _tmp38_ = NULL;
	GtkLabel* _tmp39_;
	GtkBox* deuteranopia_box = NULL;
	GtkBox* _tmp40_;
	GtkBox* _tmp41_;
	GtkLabel* _tmp42_;
	GtkBox* _tmp43_;
	DisplayFiltersViewColorSwatch* _tmp44_;
	DisplayFiltersViewColorSwatch* _tmp45_;
	GtkBox* _tmp46_;
	DisplayFiltersViewColorSwatch* _tmp47_;
	DisplayFiltersViewColorSwatch* _tmp48_;
	GtkBox* _tmp49_;
	DisplayFiltersViewColorSwatch* _tmp50_;
	DisplayFiltersViewColorSwatch* _tmp51_;
	GtkCheckButton* deuteranopia_radio = NULL;
	GtkCheckButton* _tmp52_;
	GtkCheckButton* _tmp53_;
	GtkCheckButton* _tmp54_ = NULL;
	GtkBox* _tmp55_;
	GtkCheckButton* _tmp56_;
	GtkLabel* deuteranopia_hc_label = NULL;
	gchar* _tmp57_;
	gchar* _tmp58_;
	GtkLabel* _tmp59_ = NULL;
	GtkLabel* _tmp60_;
	GtkBox* deuteranopia_hc_box = NULL;
	GtkBox* _tmp61_;
	GtkBox* _tmp62_;
	GtkLabel* _tmp63_;
	GtkCheckButton* deuteranopia_hc_radio = NULL;
	GtkCheckButton* _tmp64_;
	GtkCheckButton* _tmp65_;
	GtkCheckButton* _tmp66_ = NULL;
	GtkBox* _tmp67_;
	GtkCheckButton* _tmp68_;
	GtkLabel* tritanopia_label = NULL;
	gchar* _tmp69_;
	gchar* _tmp70_;
	GtkLabel* _tmp71_ = NULL;
	GtkLabel* _tmp72_;
	GtkBox* tritanopia_box = NULL;
	GtkBox* _tmp73_;
	GtkBox* _tmp74_;
	GtkLabel* _tmp75_;
	GtkBox* _tmp76_;
	DisplayFiltersViewColorSwatch* _tmp77_;
	DisplayFiltersViewColorSwatch* _tmp78_;
	GtkBox* _tmp79_;
	DisplayFiltersViewColorSwatch* _tmp80_;
	DisplayFiltersViewColorSwatch* _tmp81_;
	GtkCheckButton* tritanopia_radio = NULL;
	GtkCheckButton* _tmp82_;
	GtkCheckButton* _tmp83_;
	GtkCheckButton* _tmp84_ = NULL;
	GtkBox* _tmp85_;
	GtkCheckButton* _tmp86_;
	GtkAdjustment* colorblindness_adjustment = NULL;
	GtkAdjustment* _tmp87_;
	GtkScale* colorblindness_scale = NULL;
	GtkAdjustment* _tmp88_;
	GtkScale* _tmp89_ = NULL;
	GtkScale* _tmp90_;
	GtkScale* _tmp91_;
	GtkBox* colorblindness_box = NULL;
	GtkBox* _tmp92_;
	GtkBox* _tmp93_;
	GraniteHeaderLabel* _tmp94_;
	GtkBox* _tmp95_;
	GtkCheckButton* _tmp96_;
	GtkBox* _tmp97_;
	GtkCheckButton* _tmp98_;
	GtkBox* _tmp99_;
	GtkCheckButton* _tmp100_;
	GtkBox* _tmp101_;
	GtkCheckButton* _tmp102_;
	GtkBox* _tmp103_;
	GtkCheckButton* _tmp104_;
	GtkBox* _tmp105_;
	GtkCheckButton* _tmp106_;
	GtkBox* _tmp107_;
	GtkScale* _tmp108_;
	GraniteHeaderLabel* grayscale_header = NULL;
	gchar* _tmp109_;
	GraniteHeaderLabel* _tmp110_ = NULL;
	GtkSwitch* grayscale_switch = NULL;
	GtkSwitch* _tmp111_ = NULL;
	GtkAdjustment* grayscale_adjustment = NULL;
	GtkAdjustment* _tmp112_;
	GtkScale* grayscale_scale = NULL;
	GtkAdjustment* _tmp113_;
	GtkScale* _tmp114_ = NULL;
	GtkScale* _tmp115_;
	GtkScale* _tmp116_;
	GtkGrid* grayscale_grid = NULL;
	GtkGrid* _tmp117_ = NULL;
	GtkGrid* _tmp118_;
	GraniteHeaderLabel* _tmp119_;
	GtkGrid* _tmp120_;
	GtkSwitch* _tmp121_;
	GtkGrid* _tmp122_;
	GtkScale* _tmp123_;
	GtkBox* box = NULL;
	GtkBox* _tmp124_;
	GtkBox* _tmp125_;
	GtkBox* _tmp126_;
	GtkBox* _tmp127_;
	GtkGrid* _tmp128_;
	AdwClamp* clamp = NULL;
	GtkBox* _tmp129_;
	GtkWidget* _tmp130_;
	AdwClamp* _tmp131_ = NULL;
	AdwClamp* _tmp132_;
	GSettings* a11y_settings = NULL;
	GSettings* _tmp133_;
	GSettings* _tmp134_;
	GtkAdjustment* _tmp135_;
	GSettings* _tmp136_;
	GtkSwitch* _tmp137_;
	GSettings* _tmp138_;
	GtkScale* _tmp139_;
	GSettings* _tmp140_;
	GtkAdjustment* _tmp141_;
	GSettings* _tmp142_;
	GtkCheckButton* _tmp143_;
	GSettings* _tmp144_;
	GtkCheckButton* _tmp145_;
	GSettings* _tmp146_;
	GtkCheckButton* _tmp147_;
	GSettings* _tmp148_;
	GtkCheckButton* _tmp149_;
	GSettings* _tmp150_;
	GtkCheckButton* _tmp151_;
	GSettings* _tmp152_;
	GtkCheckButton* _tmp153_;
	GSettings* _tmp154_;
	GtkScale* _tmp155_;
	parent_class = G_OBJECT_CLASS (display_filters_view_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, DISPLAY_TYPE_FILTERS_VIEW, DisplayFiltersView);
	_tmp0_ = g_strdup (_ ("Each of the circles below should appear as a different color. A filter" \
" can be applied to the entire display to help differentiate between co" \
"lors."));
	_tmp1_ = granite_header_label_new (_ ("Color Deficiency Assistance"));
	granite_header_label_set_secondary_text (_tmp1_, _tmp0_);
	_g_free0 (_tmp0_);
	g_object_ref_sink (_tmp1_);
	colorblindness_header = _tmp1_;
	_tmp2_ = (GtkCheckButton*) gtk_check_button_new_with_label (_ ("None"));
	g_object_ref_sink (_tmp2_);
	none_radio = _tmp2_;
	_tmp3_ = g_strdup_printf (DISPLAY_FILTERS_VIEW_TEXT_MARKUP, _ ("Red/Green"), _ ("Protanopia"));
	_tmp4_ = _tmp3_;
	_tmp5_ = (GtkLabel*) gtk_label_new (_tmp4_);
	gtk_widget_set_halign ((GtkWidget*) _tmp5_, GTK_ALIGN_START);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp5_, TRUE);
	gtk_label_set_selectable (_tmp5_, TRUE);
	gtk_label_set_use_markup (_tmp5_, TRUE);
	g_object_ref_sink (_tmp5_);
	_tmp6_ = _tmp5_;
	_g_free0 (_tmp4_);
	protanopia_label = _tmp6_;
	_tmp7_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
	g_object_ref_sink (_tmp7_);
	protanopia_box = _tmp7_;
	_tmp8_ = protanopia_box;
	_tmp9_ = protanopia_label;
	gtk_box_append (_tmp8_, (GtkWidget*) _tmp9_);
	_tmp10_ = protanopia_box;
	_tmp11_ = display_filters_view_color_swatch_new ("green");
	g_object_ref_sink (_tmp11_);
	_tmp12_ = _tmp11_;
	gtk_box_append (_tmp10_, (GtkWidget*) _tmp12_);
	_g_object_unref0 (_tmp12_);
	_tmp13_ = protanopia_box;
	_tmp14_ = display_filters_view_color_swatch_new ("orange");
	g_object_ref_sink (_tmp14_);
	_tmp15_ = _tmp14_;
	gtk_box_append (_tmp13_, (GtkWidget*) _tmp15_);
	_g_object_unref0 (_tmp15_);
	_tmp16_ = protanopia_box;
	_tmp17_ = display_filters_view_color_swatch_new ("red");
	g_object_ref_sink (_tmp17_);
	_tmp18_ = _tmp17_;
	gtk_box_append (_tmp16_, (GtkWidget*) _tmp18_);
	_g_object_unref0 (_tmp18_);
	_tmp19_ = none_radio;
	_tmp20_ = _g_object_ref0 (_tmp19_);
	_tmp21_ = (GtkCheckButton*) gtk_check_button_new ();
	gtk_check_button_set_group (_tmp21_, _tmp20_);
	_g_object_unref0 (_tmp20_);
	g_object_ref_sink (_tmp21_);
	protanopia_radio = _tmp21_;
	_tmp22_ = protanopia_box;
	_tmp23_ = protanopia_radio;
	gtk_widget_set_parent ((GtkWidget*) _tmp22_, (GtkWidget*) _tmp23_);
	_tmp24_ = g_strdup_printf (DISPLAY_FILTERS_VIEW_TEXT_MARKUP, _ ("Red/Green — High Contrast"), _ ("Protanopia"));
	_tmp25_ = _tmp24_;
	_tmp26_ = (GtkLabel*) gtk_label_new (_tmp25_);
	gtk_widget_set_halign ((GtkWidget*) _tmp26_, GTK_ALIGN_START);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp26_, TRUE);
	gtk_label_set_selectable (_tmp26_, TRUE);
	gtk_label_set_use_markup (_tmp26_, TRUE);
	g_object_ref_sink (_tmp26_);
	_tmp27_ = _tmp26_;
	_g_free0 (_tmp25_);
	protanopia_hc_label = _tmp27_;
	_tmp28_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
	g_object_ref_sink (_tmp28_);
	protanopia_hc_box = _tmp28_;
	_tmp29_ = protanopia_hc_box;
	_tmp30_ = protanopia_hc_label;
	gtk_box_append (_tmp29_, (GtkWidget*) _tmp30_);
	_tmp31_ = none_radio;
	_tmp32_ = _g_object_ref0 (_tmp31_);
	_tmp33_ = (GtkCheckButton*) gtk_check_button_new ();
	gtk_check_button_set_group (_tmp33_, _tmp32_);
	_g_object_unref0 (_tmp32_);
	g_object_ref_sink (_tmp33_);
	protanopia_hc_radio = _tmp33_;
	_tmp34_ = protanopia_hc_box;
	_tmp35_ = protanopia_hc_radio;
	gtk_widget_set_parent ((GtkWidget*) _tmp34_, (GtkWidget*) _tmp35_);
	_tmp36_ = g_strdup_printf (DISPLAY_FILTERS_VIEW_TEXT_MARKUP, _ ("Green/Red"), _ ("Deuteranopia"));
	_tmp37_ = _tmp36_;
	_tmp38_ = (GtkLabel*) gtk_label_new (_tmp37_);
	gtk_widget_set_halign ((GtkWidget*) _tmp38_, GTK_ALIGN_START);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp38_, TRUE);
	gtk_label_set_selectable (_tmp38_, TRUE);
	gtk_label_set_use_markup (_tmp38_, TRUE);
	g_object_ref_sink (_tmp38_);
	_tmp39_ = _tmp38_;
	_g_free0 (_tmp37_);
	deuteranopia_label = _tmp39_;
	_tmp40_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
	g_object_ref_sink (_tmp40_);
	deuteranopia_box = _tmp40_;
	_tmp41_ = deuteranopia_box;
	_tmp42_ = deuteranopia_label;
	gtk_box_append (_tmp41_, (GtkWidget*) _tmp42_);
	_tmp43_ = deuteranopia_box;
	_tmp44_ = display_filters_view_color_swatch_new ("teal");
	g_object_ref_sink (_tmp44_);
	_tmp45_ = _tmp44_;
	gtk_box_append (_tmp43_, (GtkWidget*) _tmp45_);
	_g_object_unref0 (_tmp45_);
	_tmp46_ = deuteranopia_box;
	_tmp47_ = display_filters_view_color_swatch_new ("purple");
	g_object_ref_sink (_tmp47_);
	_tmp48_ = _tmp47_;
	gtk_box_append (_tmp46_, (GtkWidget*) _tmp48_);
	_g_object_unref0 (_tmp48_);
	_tmp49_ = deuteranopia_box;
	_tmp50_ = display_filters_view_color_swatch_new ("pink");
	g_object_ref_sink (_tmp50_);
	_tmp51_ = _tmp50_;
	gtk_box_append (_tmp49_, (GtkWidget*) _tmp51_);
	_g_object_unref0 (_tmp51_);
	_tmp52_ = none_radio;
	_tmp53_ = _g_object_ref0 (_tmp52_);
	_tmp54_ = (GtkCheckButton*) gtk_check_button_new ();
	gtk_check_button_set_group (_tmp54_, _tmp53_);
	_g_object_unref0 (_tmp53_);
	g_object_ref_sink (_tmp54_);
	deuteranopia_radio = _tmp54_;
	_tmp55_ = deuteranopia_box;
	_tmp56_ = deuteranopia_radio;
	gtk_widget_set_parent ((GtkWidget*) _tmp55_, (GtkWidget*) _tmp56_);
	_tmp57_ = g_strdup_printf (DISPLAY_FILTERS_VIEW_TEXT_MARKUP, _ ("Green/Red — High Contrast"), _ ("Deuteranopia"));
	_tmp58_ = _tmp57_;
	_tmp59_ = (GtkLabel*) gtk_label_new (_tmp58_);
	gtk_widget_set_halign ((GtkWidget*) _tmp59_, GTK_ALIGN_START);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp59_, TRUE);
	gtk_label_set_selectable (_tmp59_, TRUE);
	gtk_label_set_use_markup (_tmp59_, TRUE);
	g_object_ref_sink (_tmp59_);
	_tmp60_ = _tmp59_;
	_g_free0 (_tmp58_);
	deuteranopia_hc_label = _tmp60_;
	_tmp61_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
	g_object_ref_sink (_tmp61_);
	deuteranopia_hc_box = _tmp61_;
	_tmp62_ = deuteranopia_hc_box;
	_tmp63_ = deuteranopia_hc_label;
	gtk_box_append (_tmp62_, (GtkWidget*) _tmp63_);
	_tmp64_ = none_radio;
	_tmp65_ = _g_object_ref0 (_tmp64_);
	_tmp66_ = (GtkCheckButton*) gtk_check_button_new ();
	gtk_check_button_set_group (_tmp66_, _tmp65_);
	_g_object_unref0 (_tmp65_);
	g_object_ref_sink (_tmp66_);
	deuteranopia_hc_radio = _tmp66_;
	_tmp67_ = deuteranopia_hc_box;
	_tmp68_ = deuteranopia_hc_radio;
	gtk_widget_set_parent ((GtkWidget*) _tmp67_, (GtkWidget*) _tmp68_);
	_tmp69_ = g_strdup_printf (DISPLAY_FILTERS_VIEW_TEXT_MARKUP, _ ("Blue/Yellow"), _ ("Tritanopia"));
	_tmp70_ = _tmp69_;
	_tmp71_ = (GtkLabel*) gtk_label_new (_tmp70_);
	gtk_widget_set_halign ((GtkWidget*) _tmp71_, GTK_ALIGN_START);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp71_, TRUE);
	gtk_label_set_selectable (_tmp71_, TRUE);
	gtk_label_set_use_markup (_tmp71_, TRUE);
	g_object_ref_sink (_tmp71_);
	_tmp72_ = _tmp71_;
	_g_free0 (_tmp70_);
	tritanopia_label = _tmp72_;
	_tmp73_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
	g_object_ref_sink (_tmp73_);
	tritanopia_box = _tmp73_;
	_tmp74_ = tritanopia_box;
	_tmp75_ = tritanopia_label;
	gtk_box_append (_tmp74_, (GtkWidget*) _tmp75_);
	_tmp76_ = tritanopia_box;
	_tmp77_ = display_filters_view_color_swatch_new ("yellow");
	g_object_ref_sink (_tmp77_);
	_tmp78_ = _tmp77_;
	gtk_box_append (_tmp76_, (GtkWidget*) _tmp78_);
	_g_object_unref0 (_tmp78_);
	_tmp79_ = tritanopia_box;
	_tmp80_ = display_filters_view_color_swatch_new ("blue");
	g_object_ref_sink (_tmp80_);
	_tmp81_ = _tmp80_;
	gtk_box_append (_tmp79_, (GtkWidget*) _tmp81_);
	_g_object_unref0 (_tmp81_);
	_tmp82_ = none_radio;
	_tmp83_ = _g_object_ref0 (_tmp82_);
	_tmp84_ = (GtkCheckButton*) gtk_check_button_new ();
	gtk_check_button_set_group (_tmp84_, _tmp83_);
	_g_object_unref0 (_tmp83_);
	g_object_ref_sink (_tmp84_);
	tritanopia_radio = _tmp84_;
	_tmp85_ = tritanopia_box;
	_tmp86_ = tritanopia_radio;
	gtk_widget_set_parent ((GtkWidget*) _tmp85_, (GtkWidget*) _tmp86_);
	_tmp87_ = gtk_adjustment_new ((gdouble) 0, 0.15, (gdouble) 1, 0.01, (gdouble) 0, (gdouble) 0);
	g_object_ref_sink (_tmp87_);
	colorblindness_adjustment = _tmp87_;
	_tmp88_ = colorblindness_adjustment;
	_tmp89_ = (GtkScale*) gtk_scale_new (GTK_ORIENTATION_HORIZONTAL, _tmp88_);
	gtk_scale_set_draw_value (_tmp89_, FALSE);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp89_, TRUE);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp89_, 3);
	g_object_ref_sink (_tmp89_);
	colorblindness_scale = _tmp89_;
	_tmp90_ = colorblindness_scale;
	gtk_scale_add_mark (_tmp90_, 0.15, GTK_POS_BOTTOM, _ ("Less Assistance"));
	_tmp91_ = colorblindness_scale;
	gtk_scale_add_mark (_tmp91_, (gdouble) 1, GTK_POS_BOTTOM, _ ("More Assistance"));
	_tmp92_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
	g_object_ref_sink (_tmp92_);
	colorblindness_box = _tmp92_;
	_tmp93_ = colorblindness_box;
	_tmp94_ = colorblindness_header;
	gtk_box_append (_tmp93_, (GtkWidget*) _tmp94_);
	_tmp95_ = colorblindness_box;
	_tmp96_ = none_radio;
	gtk_box_append (_tmp95_, (GtkWidget*) _tmp96_);
	_tmp97_ = colorblindness_box;
	_tmp98_ = protanopia_radio;
	gtk_box_append (_tmp97_, (GtkWidget*) _tmp98_);
	_tmp99_ = colorblindness_box;
	_tmp100_ = protanopia_hc_radio;
	gtk_box_append (_tmp99_, (GtkWidget*) _tmp100_);
	_tmp101_ = colorblindness_box;
	_tmp102_ = deuteranopia_radio;
	gtk_box_append (_tmp101_, (GtkWidget*) _tmp102_);
	_tmp103_ = colorblindness_box;
	_tmp104_ = deuteranopia_hc_radio;
	gtk_box_append (_tmp103_, (GtkWidget*) _tmp104_);
	_tmp105_ = colorblindness_box;
	_tmp106_ = tritanopia_radio;
	gtk_box_append (_tmp105_, (GtkWidget*) _tmp106_);
	_tmp107_ = colorblindness_box;
	_tmp108_ = colorblindness_scale;
	gtk_box_append (_tmp107_, (GtkWidget*) _tmp108_);
	_tmp109_ = g_strdup (_ ("Reducing color can help avoid distractions and alleviate screen addict" \
"ion"));
	_tmp110_ = granite_header_label_new (_ ("Grayscale"));
	granite_header_label_set_secondary_text (_tmp110_, _tmp109_);
	_g_free0 (_tmp109_);
	g_object_ref_sink (_tmp110_);
	grayscale_header = _tmp110_;
	_tmp111_ = (GtkSwitch*) gtk_switch_new ();
	gtk_widget_set_halign ((GtkWidget*) _tmp111_, GTK_ALIGN_END);
	gtk_widget_set_valign ((GtkWidget*) _tmp111_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp111_);
	grayscale_switch = _tmp111_;
	_tmp112_ = gtk_adjustment_new ((gdouble) 0, 0.15, (gdouble) 1, 0.01, (gdouble) 0, (gdouble) 0);
	g_object_ref_sink (_tmp112_);
	grayscale_adjustment = _tmp112_;
	_tmp113_ = grayscale_adjustment;
	_tmp114_ = (GtkScale*) gtk_scale_new (GTK_ORIENTATION_HORIZONTAL, _tmp113_);
	gtk_scale_set_draw_value (_tmp114_, FALSE);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp114_, TRUE);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp114_, 6);
	g_object_ref_sink (_tmp114_);
	grayscale_scale = _tmp114_;
	_tmp115_ = grayscale_scale;
	gtk_scale_add_mark (_tmp115_, 0.15, GTK_POS_BOTTOM, _ ("More Color"));
	_tmp116_ = grayscale_scale;
	gtk_scale_add_mark (_tmp116_, (gdouble) 1, GTK_POS_BOTTOM, _ ("Less Color"));
	_tmp117_ = (GtkGrid*) gtk_grid_new ();
	gtk_grid_set_column_spacing (_tmp117_, 12);
	g_object_ref_sink (_tmp117_);
	grayscale_grid = _tmp117_;
	_tmp118_ = grayscale_grid;
	_tmp119_ = grayscale_header;
	gtk_grid_attach (_tmp118_, (GtkWidget*) _tmp119_, 0, 0, 1, 1);
	_tmp120_ = grayscale_grid;
	_tmp121_ = grayscale_switch;
	gtk_grid_attach (_tmp120_, (GtkWidget*) _tmp121_, 1, 0, 1, 1);
	_tmp122_ = grayscale_grid;
	_tmp123_ = grayscale_scale;
	gtk_grid_attach (_tmp122_, (GtkWidget*) _tmp123_, 0, 1, 2, 1);
	_tmp124_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 24);
	g_object_ref_sink (_tmp124_);
	box = _tmp124_;
	_tmp125_ = box;
	_tmp126_ = colorblindness_box;
	gtk_box_append (_tmp125_, (GtkWidget*) _tmp126_);
	_tmp127_ = box;
	_tmp128_ = grayscale_grid;
	gtk_box_append (_tmp127_, (GtkWidget*) _tmp128_);
	_tmp129_ = box;
	_tmp130_ = _g_object_ref0 ((GtkWidget*) _tmp129_);
	_tmp131_ = (AdwClamp*) adw_clamp_new ();
	adw_clamp_set_child (_tmp131_, _tmp130_);
	_g_object_unref0 (_tmp130_);
	g_object_ref_sink (_tmp131_);
	clamp = _tmp131_;
	_tmp132_ = clamp;
	gtk_box_append ((GtkBox*) self, (GtkWidget*) _tmp132_);
	gtk_widget_set_margin_start ((GtkWidget*) self, 12);
	gtk_widget_set_margin_end ((GtkWidget*) self, 12);
	gtk_widget_set_margin_bottom ((GtkWidget*) self, 12);
	_tmp133_ = g_settings_new ("io.elementary.desktop.wm.accessibility");
	a11y_settings = _tmp133_;
	_tmp134_ = a11y_settings;
	_tmp135_ = colorblindness_adjustment;
	g_settings_bind (_tmp134_, "colorblindness-correction-filter-strength", (GObject*) _tmp135_, "value", G_SETTINGS_BIND_DEFAULT);
	_tmp136_ = a11y_settings;
	_tmp137_ = grayscale_switch;
	g_settings_bind (_tmp136_, "enable-monochrome-filter", (GObject*) _tmp137_, "active", G_SETTINGS_BIND_DEFAULT);
	_tmp138_ = a11y_settings;
	_tmp139_ = grayscale_scale;
	g_settings_bind (_tmp138_, "enable-monochrome-filter", (GObject*) _tmp139_, "sensitive", G_SETTINGS_BIND_DEFAULT);
	_tmp140_ = a11y_settings;
	_tmp141_ = grayscale_adjustment;
	g_settings_bind (_tmp140_, "monochrome-filter-strength", (GObject*) _tmp141_, "value", G_SETTINGS_BIND_DEFAULT);
	_tmp142_ = a11y_settings;
	_tmp143_ = none_radio;
	g_settings_bind_with_mapping (_tmp142_, "colorblindness-correction-filter", (GObject*) _tmp143_, "active", G_SETTINGS_BIND_DEFAULT, __display_filters_view___lambda31__gsettings_bind_get_mapping, __display_filters_view___lambda32__gsettings_bind_set_mapping, NULL, NULL);
	_tmp144_ = a11y_settings;
	_tmp145_ = protanopia_radio;
	g_settings_bind_with_mapping (_tmp144_, "colorblindness-correction-filter", (GObject*) _tmp145_, "active", G_SETTINGS_BIND_DEFAULT, __display_filters_view___lambda33__gsettings_bind_get_mapping, __display_filters_view___lambda34__gsettings_bind_set_mapping, NULL, NULL);
	_tmp146_ = a11y_settings;
	_tmp147_ = protanopia_hc_radio;
	g_settings_bind_with_mapping (_tmp146_, "colorblindness-correction-filter", (GObject*) _tmp147_, "active", G_SETTINGS_BIND_DEFAULT, __display_filters_view___lambda35__gsettings_bind_get_mapping, __display_filters_view___lambda36__gsettings_bind_set_mapping, NULL, NULL);
	_tmp148_ = a11y_settings;
	_tmp149_ = deuteranopia_radio;
	g_settings_bind_with_mapping (_tmp148_, "colorblindness-correction-filter", (GObject*) _tmp149_, "active", G_SETTINGS_BIND_DEFAULT, __display_filters_view___lambda37__gsettings_bind_get_mapping, __display_filters_view___lambda38__gsettings_bind_set_mapping, NULL, NULL);
	_tmp150_ = a11y_settings;
	_tmp151_ = deuteranopia_hc_radio;
	g_settings_bind_with_mapping (_tmp150_, "colorblindness-correction-filter", (GObject*) _tmp151_, "active", G_SETTINGS_BIND_DEFAULT, __display_filters_view___lambda39__gsettings_bind_get_mapping, __display_filters_view___lambda40__gsettings_bind_set_mapping, NULL, NULL);
	_tmp152_ = a11y_settings;
	_tmp153_ = tritanopia_radio;
	g_settings_bind_with_mapping (_tmp152_, "colorblindness-correction-filter", (GObject*) _tmp153_, "active", G_SETTINGS_BIND_DEFAULT, __display_filters_view___lambda41__gsettings_bind_get_mapping, __display_filters_view___lambda42__gsettings_bind_set_mapping, NULL, NULL);
	_tmp154_ = a11y_settings;
	_tmp155_ = colorblindness_scale;
	g_settings_bind_with_mapping (_tmp154_, "colorblindness-correction-filter", (GObject*) _tmp155_, "sensitive", G_SETTINGS_BIND_GET, __display_filters_view___lambda43__gsettings_bind_get_mapping, __display_filters_view___lambda44__gsettings_bind_set_mapping, NULL, NULL);
	_g_object_unref0 (a11y_settings);
	_g_object_unref0 (clamp);
	_g_object_unref0 (box);
	_g_object_unref0 (grayscale_grid);
	_g_object_unref0 (grayscale_scale);
	_g_object_unref0 (grayscale_adjustment);
	_g_object_unref0 (grayscale_switch);
	_g_object_unref0 (grayscale_header);
	_g_object_unref0 (colorblindness_box);
	_g_object_unref0 (colorblindness_scale);
	_g_object_unref0 (colorblindness_adjustment);
	_g_object_unref0 (tritanopia_radio);
	_g_object_unref0 (tritanopia_box);
	_g_object_unref0 (tritanopia_label);
	_g_object_unref0 (deuteranopia_hc_radio);
	_g_object_unref0 (deuteranopia_hc_box);
	_g_object_unref0 (deuteranopia_hc_label);
	_g_object_unref0 (deuteranopia_radio);
	_g_object_unref0 (deuteranopia_box);
	_g_object_unref0 (deuteranopia_label);
	_g_object_unref0 (protanopia_hc_radio);
	_g_object_unref0 (protanopia_hc_box);
	_g_object_unref0 (protanopia_hc_label);
	_g_object_unref0 (protanopia_radio);
	_g_object_unref0 (protanopia_box);
	_g_object_unref0 (protanopia_label);
	_g_object_unref0 (none_radio);
	_g_object_unref0 (colorblindness_header);
	return obj;
}

static void
display_filters_view_class_init (DisplayFiltersViewClass * klass,
                                 gpointer klass_data)
{
	display_filters_view_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->constructor = display_filters_view_constructor;
}

static void
display_filters_view_instance_init (DisplayFiltersView * self,
                                    gpointer klass)
{
}

static GType
display_filters_view_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (DisplayFiltersViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) display_filters_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DisplayFiltersView), 0, (GInstanceInitFunc) display_filters_view_instance_init, NULL };
	GType display_filters_view_type_id;
	display_filters_view_type_id = g_type_register_static (gtk_box_get_type (), "DisplayFiltersView", &g_define_type_info, 0);
	return display_filters_view_type_id;
}

GType
display_filters_view_get_type (void)
{
	static volatile gsize display_filters_view_type_id__once = 0;
	if (g_once_init_enter (&display_filters_view_type_id__once)) {
		GType display_filters_view_type_id;
		display_filters_view_type_id = display_filters_view_get_type_once ();
		g_once_init_leave (&display_filters_view_type_id__once, display_filters_view_type_id);
	}
	return display_filters_view_type_id__once;
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

